window.Gleam.initSearch([{"doc":"fluentci","title":"fluentci","content":"# FluentCI Gleam SDK\n\n[![Package Version](https://img.shields.io/hexpm/v/fluentci)](https://hex.pm/packages/fluentci)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/fluentci/)\n\nThe FluentCI Gleam SDK provides a set of APIs to interact with FluentCI in Gleam, it allows you to write CI/CD pipelines in Gleam.\n\n## 🚚 Installation\n\n```sh\ngleam add fluentci\n```\n\n## 🚀 Quick Start\n\n```gleam\nimport fluentci.{dag, pipeline, set_secret}\nimport fluentci/pipeline.{stdout, with_exec, with_secret_variable}\nimport fluentci/secret.{plaintext}\nimport gleam/io\nimport gleam/javascript/array.{from_list}\nimport gleam/javascript/promise.{await, resolve}\n\npub fn main() {\n  // This pipeline will print &quot;Hello, World!&quot; to the console\n  dag()\n  |&gt; pipeline(&quot;hello-world&quot;)\n  |&gt; with_exec(from_list([&quot;echo&quot;, &quot;Hello, World!&quot;]))\n  |&gt; stdout\n  |&gt; await(fn(output) {\n    io.println(output)\n    resolve(output)\n  })\n\n  // This pipeline will print the value of a secret to the console\n  let secret = dag() |&gt; set_secret(&quot;GITHUB&quot;, &quot;my-github-token&quot;)\n  secret\n  |&gt; plaintext\n  |&gt; await(fn(value) {\n    io.println(value)\n    resolve(value)\n  })\n\n  dag()\n  |&gt; pipeline(&quot;secret-demo&quot;)\n  |&gt; with_secret_variable(&quot;GITHUB&quot;, secret)\n  |&gt; with_exec(from_list([&quot;echo&quot;, &quot;$GITHUB&quot;]))\n  |&gt; stdout\n  |&gt; await(fn(value) {\n    io.print(&quot;Secret demo: &quot;)\n    io.println(value)\n    resolve(value)\n  })\n}\n\n```\n\nRun the pipeline with the following command:\n\n```sh\nfluentci-engine run -- gleam run\n```\n\nSee [fluentci-engine](https://github.com/fluentci-io/fluentci-engine) and [fluentci](https://github.com/fluentci-io/fluentci) for more information.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/fluentci&gt;.\n","url":"index.html"},{"doc":"fluentci/cache","title":"Cache","content":"pub type Cache\n\n\nSynonyms:\nfluentci/cache.Cache\nfluentci/cache Cache","url":"fluentci/cache.html#Cache"},{"doc":"fluentci/cache","title":"id","content":"pub fn id(cache: Cache) -&gt; Promise(String)\n\nSynonyms:\nfluentci/cache.id\nfluentci/cache id","url":"fluentci/cache.html#id"},{"doc":"fluentci/cache","title":"key","content":"pub fn key(cache: Cache) -&gt; Promise(String)\n\nSynonyms:\nfluentci/cache.key\nfluentci/cache key","url":"fluentci/cache.html#key"},{"doc":"fluentci/cache","title":"fluentci/cache","content":"","url":"fluentci/cache.html"},{"doc":"fluentci/secret","title":"Secret","content":"pub type Secret\n\n\nSynonyms:\nfluentci/secret.Secret\nfluentci/secret Secret","url":"fluentci/secret.html#Secret"},{"doc":"fluentci/secret","title":"id","content":"pub fn id(secret: Secret) -&gt; Promise(String)\n\nSynonyms:\nfluentci/secret.id\nfluentci/secret id","url":"fluentci/secret.html#id"},{"doc":"fluentci/secret","title":"mount","content":"pub fn mount(secret: Secret) -&gt; Promise(String)\n\nSynonyms:\nfluentci/secret.mount\nfluentci/secret mount","url":"fluentci/secret.html#mount"},{"doc":"fluentci/secret","title":"name","content":"pub fn name(secret: Secret) -&gt; Promise(String)\n\nSynonyms:\nfluentci/secret.name\nfluentci/secret name","url":"fluentci/secret.html#name"},{"doc":"fluentci/secret","title":"plaintext","content":"pub fn plaintext(secret: Secret) -&gt; Promise(String)\n\nSynonyms:\nfluentci/secret.plaintext\nfluentci/secret plaintext","url":"fluentci/secret.html#plaintext"},{"doc":"fluentci/secret","title":"fluentci/secret","content":"","url":"fluentci/secret.html"},{"doc":"fluentci/service","title":"Service","content":"pub type Service\n\n\nSynonyms:\nfluentci/service.Service\nfluentci/service Service","url":"fluentci/service.html#Service"},{"doc":"fluentci/service","title":"id","content":"pub fn id(service: Service) -&gt; Promise(String)\n\nSynonyms:\nfluentci/service.id\nfluentci/service id","url":"fluentci/service.html#id"},{"doc":"fluentci/service","title":"fluentci/service","content":"","url":"fluentci/service.html"},{"doc":"fluentci/devbox","title":"Devbox","content":"pub type Devbox\n\n\nSynonyms:\nfluentci/devbox.Devbox\nfluentci/devbox Devbox","url":"fluentci/devbox.html#Devbox"},{"doc":"fluentci/devbox","title":"as_service","content":"pub fn as_service(devbox: Devbox) -&gt; Service\n\nSynonyms:\nfluentci/devbox.as_service\nfluentci/devbox as_service","url":"fluentci/devbox.html#as_service"},{"doc":"fluentci/devbox","title":"id","content":"pub fn id(devbox: Devbox) -&gt; Promise(String)\n\nSynonyms:\nfluentci/devbox.id\nfluentci/devbox id","url":"fluentci/devbox.html#id"},{"doc":"fluentci/devbox","title":"stderr","content":"pub fn stderr(devbox: Devbox) -&gt; Promise(String)\n\nSynonyms:\nfluentci/devbox.stderr\nfluentci/devbox stderr","url":"fluentci/devbox.html#stderr"},{"doc":"fluentci/devbox","title":"stdout","content":"pub fn stdout(devbox: Devbox) -&gt; Promise(String)\n\nSynonyms:\nfluentci/devbox.stdout\nfluentci/devbox stdout","url":"fluentci/devbox.html#stdout"},{"doc":"fluentci/devbox","title":"wait_on","content":"pub fn wait_on(devbox: Devbox, port: a, timeout: a) -&gt; Devbox\n\nSynonyms:\nfluentci/devbox.wait_on\nfluentci/devbox wait_on","url":"fluentci/devbox.html#wait_on"},{"doc":"fluentci/devbox","title":"with_cache","content":"pub fn with_cache(devbox: Devbox, cache: Cache) -&gt; Devbox\n\nSynonyms:\nfluentci/devbox.with_cache\nfluentci/devbox with_cache","url":"fluentci/devbox.html#with_cache"},{"doc":"fluentci/devbox","title":"with_env_variable","content":"pub fn with_env_variable(\n  devbox: Devbox,\n  name: String,\n  value: String,\n) -&gt; Devbox\n\nSynonyms:\nfluentci/devbox.with_env_variable\nfluentci/devbox with_env_variable","url":"fluentci/devbox.html#with_env_variable"},{"doc":"fluentci/devbox","title":"with_exec","content":"pub fn with_exec(\n  devbox: Devbox,\n  command: Array(String),\n) -&gt; Devbox\n\nSynonyms:\nfluentci/devbox.with_exec\nfluentci/devbox with_exec","url":"fluentci/devbox.html#with_exec"},{"doc":"fluentci/devbox","title":"with_secret_variable","content":"pub fn with_secret_variable(\n  devbox: Devbox,\n  name: String,\n  secret: Secret,\n) -&gt; Devbox\n\nSynonyms:\nfluentci/devbox.with_secret_variable\nfluentci/devbox with_secret_variable","url":"fluentci/devbox.html#with_secret_variable"},{"doc":"fluentci/devbox","title":"with_service","content":"pub fn with_service(devbox: Devbox, service: Service) -&gt; Devbox\n\nSynonyms:\nfluentci/devbox.with_service\nfluentci/devbox with_service","url":"fluentci/devbox.html#with_service"},{"doc":"fluentci/devbox","title":"with_workdir","content":"pub fn with_workdir(devbox: Devbox, path: String) -&gt; Devbox\n\nSynonyms:\nfluentci/devbox.with_workdir\nfluentci/devbox with_workdir","url":"fluentci/devbox.html#with_workdir"},{"doc":"fluentci/devbox","title":"fluentci/devbox","content":"","url":"fluentci/devbox.html"},{"doc":"fluentci/devenv","title":"Devenv","content":"pub type Devenv\n\n\nSynonyms:\nfluentci/devenv.Devenv\nfluentci/devenv Devenv","url":"fluentci/devenv.html#Devenv"},{"doc":"fluentci/devenv","title":"as_service","content":"pub fn as_service(devenv: Devenv) -&gt; Service\n\nSynonyms:\nfluentci/devenv.as_service\nfluentci/devenv as_service","url":"fluentci/devenv.html#as_service"},{"doc":"fluentci/devenv","title":"id","content":"pub fn id(devenv: Devenv) -&gt; Promise(String)\n\nSynonyms:\nfluentci/devenv.id\nfluentci/devenv id","url":"fluentci/devenv.html#id"},{"doc":"fluentci/devenv","title":"stderr","content":"pub fn stderr(devenv: Devenv) -&gt; Promise(String)\n\nSynonyms:\nfluentci/devenv.stderr\nfluentci/devenv stderr","url":"fluentci/devenv.html#stderr"},{"doc":"fluentci/devenv","title":"stdout","content":"pub fn stdout(devenv: Devenv) -&gt; Promise(String)\n\nSynonyms:\nfluentci/devenv.stdout\nfluentci/devenv stdout","url":"fluentci/devenv.html#stdout"},{"doc":"fluentci/devenv","title":"wait_on","content":"pub fn wait_on(devenv: Devenv, port: a, timeout: a) -&gt; Devenv\n\nSynonyms:\nfluentci/devenv.wait_on\nfluentci/devenv wait_on","url":"fluentci/devenv.html#wait_on"},{"doc":"fluentci/devenv","title":"with_cache","content":"pub fn with_cache(devenv: Devenv, cache: Cache) -&gt; Devenv\n\nSynonyms:\nfluentci/devenv.with_cache\nfluentci/devenv with_cache","url":"fluentci/devenv.html#with_cache"},{"doc":"fluentci/devenv","title":"with_env_variable","content":"pub fn with_env_variable(\n  devenv: Devenv,\n  name: String,\n  value: String,\n) -&gt; Devenv\n\nSynonyms:\nfluentci/devenv.with_env_variable\nfluentci/devenv with_env_variable","url":"fluentci/devenv.html#with_env_variable"},{"doc":"fluentci/devenv","title":"with_exec","content":"pub fn with_exec(\n  devenv: Devenv,\n  command: Array(String),\n) -&gt; Devenv\n\nSynonyms:\nfluentci/devenv.with_exec\nfluentci/devenv with_exec","url":"fluentci/devenv.html#with_exec"},{"doc":"fluentci/devenv","title":"with_secret_variable","content":"pub fn with_secret_variable(\n  devenv: Devenv,\n  name: String,\n  secret: Secret,\n) -&gt; Devenv\n\nSynonyms:\nfluentci/devenv.with_secret_variable\nfluentci/devenv with_secret_variable","url":"fluentci/devenv.html#with_secret_variable"},{"doc":"fluentci/devenv","title":"with_service","content":"pub fn with_service(devenv: Devenv, service: Service) -&gt; Devenv\n\nSynonyms:\nfluentci/devenv.with_service\nfluentci/devenv with_service","url":"fluentci/devenv.html#with_service"},{"doc":"fluentci/devenv","title":"with_workdir","content":"pub fn with_workdir(devenv: Devenv, path: String) -&gt; Devenv\n\nSynonyms:\nfluentci/devenv.with_workdir\nfluentci/devenv with_workdir","url":"fluentci/devenv.html#with_workdir"},{"doc":"fluentci/devenv","title":"fluentci/devenv","content":"","url":"fluentci/devenv.html"},{"doc":"fluentci/flox","title":"Flox","content":"pub type Flox\n\n\nSynonyms:\nfluentci/flox.Flox\nfluentci/flox Flox","url":"fluentci/flox.html#Flox"},{"doc":"fluentci/flox","title":"as_service","content":"pub fn as_service(flox: Flox) -&gt; Service\n\nSynonyms:\nfluentci/flox.as_service\nfluentci/flox as_service","url":"fluentci/flox.html#as_service"},{"doc":"fluentci/flox","title":"id","content":"pub fn id(flox: Flox) -&gt; Promise(String)\n\nSynonyms:\nfluentci/flox.id\nfluentci/flox id","url":"fluentci/flox.html#id"},{"doc":"fluentci/flox","title":"stderr","content":"pub fn stderr(flox: Flox) -&gt; Promise(String)\n\nSynonyms:\nfluentci/flox.stderr\nfluentci/flox stderr","url":"fluentci/flox.html#stderr"},{"doc":"fluentci/flox","title":"stdout","content":"pub fn stdout(flox: Flox) -&gt; Promise(String)\n\nSynonyms:\nfluentci/flox.stdout\nfluentci/flox stdout","url":"fluentci/flox.html#stdout"},{"doc":"fluentci/flox","title":"wait_on","content":"pub fn wait_on(flox: Flox, port: a, timeout: a) -&gt; Flox\n\nSynonyms:\nfluentci/flox.wait_on\nfluentci/flox wait_on","url":"fluentci/flox.html#wait_on"},{"doc":"fluentci/flox","title":"with_cache","content":"pub fn with_cache(flox: Flox, cache: Cache) -&gt; Flox\n\nSynonyms:\nfluentci/flox.with_cache\nfluentci/flox with_cache","url":"fluentci/flox.html#with_cache"},{"doc":"fluentci/flox","title":"with_env_variable","content":"pub fn with_env_variable(\n  flox: Flox,\n  name: String,\n  value: String,\n) -&gt; Flox\n\nSynonyms:\nfluentci/flox.with_env_variable\nfluentci/flox with_env_variable","url":"fluentci/flox.html#with_env_variable"},{"doc":"fluentci/flox","title":"with_exec","content":"pub fn with_exec(flox: Flox, command: Array(String)) -&gt; Flox\n\nSynonyms:\nfluentci/flox.with_exec\nfluentci/flox with_exec","url":"fluentci/flox.html#with_exec"},{"doc":"fluentci/flox","title":"with_secret_variable","content":"pub fn with_secret_variable(\n  flox: Flox,\n  name: String,\n  secret: Secret,\n) -&gt; Flox\n\nSynonyms:\nfluentci/flox.with_secret_variable\nfluentci/flox with_secret_variable","url":"fluentci/flox.html#with_secret_variable"},{"doc":"fluentci/flox","title":"with_service","content":"pub fn with_service(flox: Flox, service: Service) -&gt; Flox\n\nSynonyms:\nfluentci/flox.with_service\nfluentci/flox with_service","url":"fluentci/flox.html#with_service"},{"doc":"fluentci/flox","title":"with_workdir","content":"pub fn with_workdir(flox: Flox, path: String) -&gt; Flox\n\nSynonyms:\nfluentci/flox.with_workdir\nfluentci/flox with_workdir","url":"fluentci/flox.html#with_workdir"},{"doc":"fluentci/flox","title":"fluentci/flox","content":"","url":"fluentci/flox.html"},{"doc":"fluentci/mise","title":"Mise","content":"pub type Mise\n\n\nSynonyms:\nfluentci/mise.Mise\nfluentci/mise Mise","url":"fluentci/mise.html#Mise"},{"doc":"fluentci/mise","title":"as_service","content":"pub fn as_service(mise: Mise) -&gt; Service\n\nSynonyms:\nfluentci/mise.as_service\nfluentci/mise as_service","url":"fluentci/mise.html#as_service"},{"doc":"fluentci/mise","title":"id","content":"pub fn id(mise: Mise) -&gt; Promise(String)\n\nSynonyms:\nfluentci/mise.id\nfluentci/mise id","url":"fluentci/mise.html#id"},{"doc":"fluentci/mise","title":"stderr","content":"pub fn stderr(mise: Mise) -&gt; Promise(String)\n\nSynonyms:\nfluentci/mise.stderr\nfluentci/mise stderr","url":"fluentci/mise.html#stderr"},{"doc":"fluentci/mise","title":"stdout","content":"pub fn stdout(mise: Mise) -&gt; Promise(String)\n\nSynonyms:\nfluentci/mise.stdout\nfluentci/mise stdout","url":"fluentci/mise.html#stdout"},{"doc":"fluentci/mise","title":"wait_on","content":"pub fn wait_on(mise: Mise, port: a, timeout: a) -&gt; Mise\n\nSynonyms:\nfluentci/mise.wait_on\nfluentci/mise wait_on","url":"fluentci/mise.html#wait_on"},{"doc":"fluentci/mise","title":"with_cache","content":"pub fn with_cache(mise: Mise, cache: Cache) -&gt; Mise\n\nSynonyms:\nfluentci/mise.with_cache\nfluentci/mise with_cache","url":"fluentci/mise.html#with_cache"},{"doc":"fluentci/mise","title":"with_env_variable","content":"pub fn with_env_variable(\n  mise: Mise,\n  name: String,\n  value: String,\n) -&gt; Mise\n\nSynonyms:\nfluentci/mise.with_env_variable\nfluentci/mise with_env_variable","url":"fluentci/mise.html#with_env_variable"},{"doc":"fluentci/mise","title":"with_exec","content":"pub fn with_exec(mise: Mise, command: Array(String)) -&gt; Mise\n\nSynonyms:\nfluentci/mise.with_exec\nfluentci/mise with_exec","url":"fluentci/mise.html#with_exec"},{"doc":"fluentci/mise","title":"with_secret_variable","content":"pub fn with_secret_variable(\n  mise: Mise,\n  name: String,\n  secret: Secret,\n) -&gt; Mise\n\nSynonyms:\nfluentci/mise.with_secret_variable\nfluentci/mise with_secret_variable","url":"fluentci/mise.html#with_secret_variable"},{"doc":"fluentci/mise","title":"with_service","content":"pub fn with_service(mise: Mise, service: Service) -&gt; Mise\n\nSynonyms:\nfluentci/mise.with_service\nfluentci/mise with_service","url":"fluentci/mise.html#with_service"},{"doc":"fluentci/mise","title":"with_workdir","content":"pub fn with_workdir(mise: Mise, path: String) -&gt; Mise\n\nSynonyms:\nfluentci/mise.with_workdir\nfluentci/mise with_workdir","url":"fluentci/mise.html#with_workdir"},{"doc":"fluentci/mise","title":"fluentci/mise","content":"","url":"fluentci/mise.html"},{"doc":"fluentci/nix","title":"Nix","content":"pub type Nix\n\n\nSynonyms:\nfluentci/nix.Nix\nfluentci/nix Nix","url":"fluentci/nix.html#Nix"},{"doc":"fluentci/nix","title":"as_service","content":"pub fn as_service(nix: Nix) -&gt; Service\n\nSynonyms:\nfluentci/nix.as_service\nfluentci/nix as_service","url":"fluentci/nix.html#as_service"},{"doc":"fluentci/nix","title":"id","content":"pub fn id(nix: Nix) -&gt; Promise(String)\n\nSynonyms:\nfluentci/nix.id\nfluentci/nix id","url":"fluentci/nix.html#id"},{"doc":"fluentci/nix","title":"stderr","content":"pub fn stderr(nix: Nix) -&gt; Promise(String)\n\nSynonyms:\nfluentci/nix.stderr\nfluentci/nix stderr","url":"fluentci/nix.html#stderr"},{"doc":"fluentci/nix","title":"stdout","content":"pub fn stdout(nix: Nix) -&gt; Promise(String)\n\nSynonyms:\nfluentci/nix.stdout\nfluentci/nix stdout","url":"fluentci/nix.html#stdout"},{"doc":"fluentci/nix","title":"wait_on","content":"pub fn wait_on(nix: Nix, port: a, timeout: a) -&gt; Nix\n\nSynonyms:\nfluentci/nix.wait_on\nfluentci/nix wait_on","url":"fluentci/nix.html#wait_on"},{"doc":"fluentci/nix","title":"with_cache","content":"pub fn with_cache(nix: Nix, cache: Cache) -&gt; Nix\n\nSynonyms:\nfluentci/nix.with_cache\nfluentci/nix with_cache","url":"fluentci/nix.html#with_cache"},{"doc":"fluentci/nix","title":"with_env_variable","content":"pub fn with_env_variable(\n  nix: Nix,\n  name: String,\n  value: String,\n) -&gt; Nix\n\nSynonyms:\nfluentci/nix.with_env_variable\nfluentci/nix with_env_variable","url":"fluentci/nix.html#with_env_variable"},{"doc":"fluentci/nix","title":"with_exec","content":"pub fn with_exec(nix: Nix, command: Array(String)) -&gt; Nix\n\nSynonyms:\nfluentci/nix.with_exec\nfluentci/nix with_exec","url":"fluentci/nix.html#with_exec"},{"doc":"fluentci/nix","title":"with_secret_variable","content":"pub fn with_secret_variable(\n  nix: Nix,\n  name: String,\n  secret: Secret,\n) -&gt; Nix\n\nSynonyms:\nfluentci/nix.with_secret_variable\nfluentci/nix with_secret_variable","url":"fluentci/nix.html#with_secret_variable"},{"doc":"fluentci/nix","title":"with_service","content":"pub fn with_service(nix: Nix, service: Service) -&gt; Nix\n\nSynonyms:\nfluentci/nix.with_service\nfluentci/nix with_service","url":"fluentci/nix.html#with_service"},{"doc":"fluentci/nix","title":"with_workdir","content":"pub fn with_workdir(nix: Nix, path: String) -&gt; Nix\n\nSynonyms:\nfluentci/nix.with_workdir\nfluentci/nix with_workdir","url":"fluentci/nix.html#with_workdir"},{"doc":"fluentci/nix","title":"fluentci/nix","content":"","url":"fluentci/nix.html"},{"doc":"fluentci/pixi","title":"Pixi","content":"pub type Pixi\n\n\nSynonyms:\nfluentci/pixi.Pixi\nfluentci/pixi Pixi","url":"fluentci/pixi.html#Pixi"},{"doc":"fluentci/pixi","title":"as_service","content":"pub fn as_service(pixi: Pixi) -&gt; Service\n\nSynonyms:\nfluentci/pixi.as_service\nfluentci/pixi as_service","url":"fluentci/pixi.html#as_service"},{"doc":"fluentci/pixi","title":"id","content":"pub fn id(pixi: Pixi) -&gt; Promise(String)\n\nSynonyms:\nfluentci/pixi.id\nfluentci/pixi id","url":"fluentci/pixi.html#id"},{"doc":"fluentci/pixi","title":"stderr","content":"pub fn stderr(pixi: Pixi) -&gt; Promise(String)\n\nSynonyms:\nfluentci/pixi.stderr\nfluentci/pixi stderr","url":"fluentci/pixi.html#stderr"},{"doc":"fluentci/pixi","title":"stdout","content":"pub fn stdout(pixi: Pixi) -&gt; Promise(String)\n\nSynonyms:\nfluentci/pixi.stdout\nfluentci/pixi stdout","url":"fluentci/pixi.html#stdout"},{"doc":"fluentci/pixi","title":"wait_on","content":"pub fn wait_on(pixi: Pixi, port: a, timeout: a) -&gt; Pixi\n\nSynonyms:\nfluentci/pixi.wait_on\nfluentci/pixi wait_on","url":"fluentci/pixi.html#wait_on"},{"doc":"fluentci/pixi","title":"with_cache","content":"pub fn with_cache(pixi: Pixi, cache: Cache) -&gt; Pixi\n\nSynonyms:\nfluentci/pixi.with_cache\nfluentci/pixi with_cache","url":"fluentci/pixi.html#with_cache"},{"doc":"fluentci/pixi","title":"with_env_variable","content":"pub fn with_env_variable(\n  pixi: Pixi,\n  name: String,\n  value: String,\n) -&gt; Pixi\n\nSynonyms:\nfluentci/pixi.with_env_variable\nfluentci/pixi with_env_variable","url":"fluentci/pixi.html#with_env_variable"},{"doc":"fluentci/pixi","title":"with_exec","content":"pub fn with_exec(pixi: Pixi, command: Array(String)) -&gt; Pixi\n\nSynonyms:\nfluentci/pixi.with_exec\nfluentci/pixi with_exec","url":"fluentci/pixi.html#with_exec"},{"doc":"fluentci/pixi","title":"with_secret_variable","content":"pub fn with_secret_variable(\n  pixi: Pixi,\n  name: String,\n  secret: Secret,\n) -&gt; Pixi\n\nSynonyms:\nfluentci/pixi.with_secret_variable\nfluentci/pixi with_secret_variable","url":"fluentci/pixi.html#with_secret_variable"},{"doc":"fluentci/pixi","title":"with_service","content":"pub fn with_service(pixi: Pixi, service: Service) -&gt; Pixi\n\nSynonyms:\nfluentci/pixi.with_service\nfluentci/pixi with_service","url":"fluentci/pixi.html#with_service"},{"doc":"fluentci/pixi","title":"with_workdir","content":"pub fn with_workdir(pixi: Pixi, path: String) -&gt; Pixi\n\nSynonyms:\nfluentci/pixi.with_workdir\nfluentci/pixi with_workdir","url":"fluentci/pixi.html#with_workdir"},{"doc":"fluentci/pixi","title":"fluentci/pixi","content":"","url":"fluentci/pixi.html"},{"doc":"fluentci/pkgx","title":"Pkgx","content":"pub type Pkgx\n\n\nSynonyms:\nfluentci/pkgx.Pkgx\nfluentci/pkgx Pkgx","url":"fluentci/pkgx.html#Pkgx"},{"doc":"fluentci/pkgx","title":"as_service","content":"pub fn as_service(pkgx: Pkgx) -&gt; Service\n\nSynonyms:\nfluentci/pkgx.as_service\nfluentci/pkgx as_service","url":"fluentci/pkgx.html#as_service"},{"doc":"fluentci/pkgx","title":"id","content":"pub fn id(pkgx: Pkgx) -&gt; Promise(String)\n\nSynonyms:\nfluentci/pkgx.id\nfluentci/pkgx id","url":"fluentci/pkgx.html#id"},{"doc":"fluentci/pkgx","title":"stderr","content":"pub fn stderr(pkgx: Pkgx) -&gt; Promise(String)\n\nSynonyms:\nfluentci/pkgx.stderr\nfluentci/pkgx stderr","url":"fluentci/pkgx.html#stderr"},{"doc":"fluentci/pkgx","title":"stdout","content":"pub fn stdout(pkgx: Pkgx) -&gt; Promise(String)\n\nSynonyms:\nfluentci/pkgx.stdout\nfluentci/pkgx stdout","url":"fluentci/pkgx.html#stdout"},{"doc":"fluentci/pkgx","title":"wait_on","content":"pub fn wait_on(pkgx: Pkgx, port: a, timeout: a) -&gt; Pkgx\n\nSynonyms:\nfluentci/pkgx.wait_on\nfluentci/pkgx wait_on","url":"fluentci/pkgx.html#wait_on"},{"doc":"fluentci/pkgx","title":"with_cache","content":"pub fn with_cache(pkgx: Pkgx, cache: Cache) -&gt; Pkgx\n\nSynonyms:\nfluentci/pkgx.with_cache\nfluentci/pkgx with_cache","url":"fluentci/pkgx.html#with_cache"},{"doc":"fluentci/pkgx","title":"with_env_variable","content":"pub fn with_env_variable(\n  pkgx: Pkgx,\n  name: String,\n  value: String,\n) -&gt; Pkgx\n\nSynonyms:\nfluentci/pkgx.with_env_variable\nfluentci/pkgx with_env_variable","url":"fluentci/pkgx.html#with_env_variable"},{"doc":"fluentci/pkgx","title":"with_exec","content":"pub fn with_exec(pkgx: Pkgx, command: Array(String)) -&gt; Pkgx\n\nSynonyms:\nfluentci/pkgx.with_exec\nfluentci/pkgx with_exec","url":"fluentci/pkgx.html#with_exec"},{"doc":"fluentci/pkgx","title":"with_packages","content":"pub fn with_packages(pkgx: Pkgx, packages: Array(String)) -&gt; Pkgx\n\nSynonyms:\nfluentci/pkgx.with_packages\nfluentci/pkgx with_packages","url":"fluentci/pkgx.html#with_packages"},{"doc":"fluentci/pkgx","title":"with_secret_variable","content":"pub fn with_secret_variable(\n  pkgx: Pkgx,\n  name: String,\n  secret: Secret,\n) -&gt; Pkgx\n\nSynonyms:\nfluentci/pkgx.with_secret_variable\nfluentci/pkgx with_secret_variable","url":"fluentci/pkgx.html#with_secret_variable"},{"doc":"fluentci/pkgx","title":"with_service","content":"pub fn with_service(pkgx: Pkgx, service: Service) -&gt; Pkgx\n\nSynonyms:\nfluentci/pkgx.with_service\nfluentci/pkgx with_service","url":"fluentci/pkgx.html#with_service"},{"doc":"fluentci/pkgx","title":"with_workdir","content":"pub fn with_workdir(pkgx: Pkgx, path: String) -&gt; Pkgx\n\nSynonyms:\nfluentci/pkgx.with_workdir\nfluentci/pkgx with_workdir","url":"fluentci/pkgx.html#with_workdir"},{"doc":"fluentci/pkgx","title":"fluentci/pkgx","content":"","url":"fluentci/pkgx.html"},{"doc":"fluentci/directory","title":"Directory","content":"pub type Directory\n\n\nSynonyms:\nfluentci/directory.Directory\nfluentci/directory Directory","url":"fluentci/directory.html#Directory"},{"doc":"fluentci/directory","title":"File","content":"pub type File\n\n\nSynonyms:\nfluentci/directory.File\nfluentci/directory File","url":"fluentci/directory.html#File"},{"doc":"fluentci/directory","title":"devbox","content":"pub fn devbox(d: Directory) -&gt; Devbox\n\nSynonyms:\nfluentci/directory.devbox\nfluentci/directory devbox","url":"fluentci/directory.html#devbox"},{"doc":"fluentci/directory","title":"devenv","content":"pub fn devenv(d: Directory) -&gt; Devenv\n\nSynonyms:\nfluentci/directory.devenv\nfluentci/directory devenv","url":"fluentci/directory.html#devenv"},{"doc":"fluentci/directory","title":"directory","content":"pub fn directory(d: Directory, path: String) -&gt; Directory\n\nSynonyms:\nfluentci/directory.directory\nfluentci/directory directory","url":"fluentci/directory.html#directory"},{"doc":"fluentci/directory","title":"entries","content":"pub fn entries(d: Directory) -&gt; Promise(Array(String))\n\nSynonyms:\nfluentci/directory.entries\nfluentci/directory entries","url":"fluentci/directory.html#entries"},{"doc":"fluentci/directory","title":"flox","content":"pub fn flox(d: Directory) -&gt; Flox\n\nSynonyms:\nfluentci/directory.flox\nfluentci/directory flox","url":"fluentci/directory.html#flox"},{"doc":"fluentci/directory","title":"mise","content":"pub fn mise(d: Directory) -&gt; Mise\n\nSynonyms:\nfluentci/directory.mise\nfluentci/directory mise","url":"fluentci/directory.html#mise"},{"doc":"fluentci/directory","title":"nix","content":"pub fn nix(d: Directory) -&gt; Nix\n\nSynonyms:\nfluentci/directory.nix\nfluentci/directory nix","url":"fluentci/directory.html#nix"},{"doc":"fluentci/directory","title":"pixi","content":"pub fn pixi(d: Directory) -&gt; Pixi\n\nSynonyms:\nfluentci/directory.pixi\nfluentci/directory pixi","url":"fluentci/directory.html#pixi"},{"doc":"fluentci/directory","title":"pkgx","content":"pub fn pkgx(d: Directory) -&gt; Pkgx\n\nSynonyms:\nfluentci/directory.pkgx\nfluentci/directory pkgx","url":"fluentci/directory.html#pkgx"},{"doc":"fluentci/directory","title":"stderr","content":"pub fn stderr(d: Directory) -&gt; Promise(String)\n\nSynonyms:\nfluentci/directory.stderr\nfluentci/directory stderr","url":"fluentci/directory.html#stderr"},{"doc":"fluentci/directory","title":"stdout","content":"pub fn stdout(d: Directory) -&gt; Promise(String)\n\nSynonyms:\nfluentci/directory.stdout\nfluentci/directory stdout","url":"fluentci/directory.html#stdout"},{"doc":"fluentci/directory","title":"tar_czvf","content":"pub fn tar_czvf(d: Directory) -&gt; File\n\nSynonyms:\nfluentci/directory.tar_czvf\nfluentci/directory tar_czvf","url":"fluentci/directory.html#tar_czvf"},{"doc":"fluentci/directory","title":"wait_on","content":"pub fn wait_on(d: Directory, port: a, timeout: a) -&gt; Directory\n\nSynonyms:\nfluentci/directory.wait_on\nfluentci/directory wait_on","url":"fluentci/directory.html#wait_on"},{"doc":"fluentci/directory","title":"with_cache","content":"pub fn with_cache(d: Directory, cache: Cache) -&gt; Directory\n\nSynonyms:\nfluentci/directory.with_cache\nfluentci/directory with_cache","url":"fluentci/directory.html#with_cache"},{"doc":"fluentci/directory","title":"with_env_variable","content":"pub fn with_env_variable(\n  d: Directory,\n  name: String,\n  value: String,\n) -&gt; Directory\n\nSynonyms:\nfluentci/directory.with_env_variable\nfluentci/directory with_env_variable","url":"fluentci/directory.html#with_env_variable"},{"doc":"fluentci/directory","title":"with_exec","content":"pub fn with_exec(\n  d: Directory,\n  command: Array(String),\n) -&gt; Directory\n\nSynonyms:\nfluentci/directory.with_exec\nfluentci/directory with_exec","url":"fluentci/directory.html#with_exec"},{"doc":"fluentci/directory","title":"with_file","content":"pub fn with_file(d: Directory, file_id: String) -&gt; Directory\n\nSynonyms:\nfluentci/directory.with_file\nfluentci/directory with_file","url":"fluentci/directory.html#with_file"},{"doc":"fluentci/directory","title":"with_secret_variable","content":"pub fn with_secret_variable(\n  d: Directory,\n  name: String,\n  secret: Secret,\n) -&gt; Directory\n\nSynonyms:\nfluentci/directory.with_secret_variable\nfluentci/directory with_secret_variable","url":"fluentci/directory.html#with_secret_variable"},{"doc":"fluentci/directory","title":"with_service","content":"pub fn with_service(d: Directory, service: Service) -&gt; Directory\n\nSynonyms:\nfluentci/directory.with_service\nfluentci/directory with_service","url":"fluentci/directory.html#with_service"},{"doc":"fluentci/directory","title":"with_workdir","content":"pub fn with_workdir(d: Directory, path: String) -&gt; Directory\n\nSynonyms:\nfluentci/directory.with_workdir\nfluentci/directory with_workdir","url":"fluentci/directory.html#with_workdir"},{"doc":"fluentci/directory","title":"zip","content":"pub fn zip(d: Directory) -&gt; File\n\nSynonyms:\nfluentci/directory.zip\nfluentci/directory zip","url":"fluentci/directory.html#zip"},{"doc":"fluentci/directory","title":"fluentci/directory","content":"","url":"fluentci/directory.html"},{"doc":"fluentci/git","title":"Git","content":"pub type Git\n\n\nSynonyms:\nfluentci/git.Git\nfluentci/git Git","url":"fluentci/git.html#Git"},{"doc":"fluentci/git","title":"branch","content":"pub fn branch(g: Git, name: String) -&gt; Git\n\nSynonyms:\nfluentci/git.branch\nfluentci/git branch","url":"fluentci/git.html#branch"},{"doc":"fluentci/git","title":"commit","content":"pub fn commit(g: Git) -&gt; Git\n\nSynonyms:\nfluentci/git.commit\nfluentci/git commit","url":"fluentci/git.html#commit"},{"doc":"fluentci/git","title":"id","content":"pub fn id(g: Git) -&gt; Promise(String)\n\nSynonyms:\nfluentci/git.id\nfluentci/git id","url":"fluentci/git.html#id"},{"doc":"fluentci/git","title":"tree","content":"pub fn tree(g: Git) -&gt; Directory\n\nSynonyms:\nfluentci/git.tree\nfluentci/git tree","url":"fluentci/git.html#tree"},{"doc":"fluentci/git","title":"fluentci/git","content":"","url":"fluentci/git.html"},{"doc":"fluentci/envhub","title":"Envhub","content":"pub type Envhub\n\n\nSynonyms:\nfluentci/envhub.Envhub\nfluentci/envhub Envhub","url":"fluentci/envhub.html#Envhub"},{"doc":"fluentci/envhub","title":"as_service","content":"pub fn as_service(envhub: Envhub) -&gt; Service\n\nSynonyms:\nfluentci/envhub.as_service\nfluentci/envhub as_service","url":"fluentci/envhub.html#as_service"},{"doc":"fluentci/envhub","title":"id","content":"pub fn id(envhub: Envhub) -&gt; Promise(String)\n\nSynonyms:\nfluentci/envhub.id\nfluentci/envhub id","url":"fluentci/envhub.html#id"},{"doc":"fluentci/envhub","title":"stderr","content":"pub fn stderr(envhub: Envhub) -&gt; Promise(String)\n\nSynonyms:\nfluentci/envhub.stderr\nfluentci/envhub stderr","url":"fluentci/envhub.html#stderr"},{"doc":"fluentci/envhub","title":"stdout","content":"pub fn stdout(envhub: Envhub) -&gt; Promise(String)\n\nSynonyms:\nfluentci/envhub.stdout\nfluentci/envhub stdout","url":"fluentci/envhub.html#stdout"},{"doc":"fluentci/envhub","title":"use_environment","content":"pub fn use_environment(\n  envhub: Envhub,\n  environment: String,\n) -&gt; Envhub\n\nSynonyms:\nfluentci/envhub.use_environment\nfluentci/envhub use_environment","url":"fluentci/envhub.html#use_environment"},{"doc":"fluentci/envhub","title":"wait_on","content":"pub fn wait_on(envhub: Envhub, port: a, timeout: a) -&gt; Envhub\n\nSynonyms:\nfluentci/envhub.wait_on\nfluentci/envhub wait_on","url":"fluentci/envhub.html#wait_on"},{"doc":"fluentci/envhub","title":"with_cache","content":"pub fn with_cache(envhub: Envhub, cache: Cache) -&gt; Envhub\n\nSynonyms:\nfluentci/envhub.with_cache\nfluentci/envhub with_cache","url":"fluentci/envhub.html#with_cache"},{"doc":"fluentci/envhub","title":"with_env_variable","content":"pub fn with_env_variable(\n  envhub: Envhub,\n  name: String,\n  value: String,\n) -&gt; Envhub\n\nSynonyms:\nfluentci/envhub.with_env_variable\nfluentci/envhub with_env_variable","url":"fluentci/envhub.html#with_env_variable"},{"doc":"fluentci/envhub","title":"with_exec","content":"pub fn with_exec(\n  envhub: Envhub,\n  command: Array(String),\n) -&gt; Envhub\n\nSynonyms:\nfluentci/envhub.with_exec\nfluentci/envhub with_exec","url":"fluentci/envhub.html#with_exec"},{"doc":"fluentci/envhub","title":"with_secret_variable","content":"pub fn with_secret_variable(\n  envhub: Envhub,\n  name: String,\n  secret: Secret,\n) -&gt; Envhub\n\nSynonyms:\nfluentci/envhub.with_secret_variable\nfluentci/envhub with_secret_variable","url":"fluentci/envhub.html#with_secret_variable"},{"doc":"fluentci/envhub","title":"with_service","content":"pub fn with_service(envhub: Envhub, service: Service) -&gt; Envhub\n\nSynonyms:\nfluentci/envhub.with_service\nfluentci/envhub with_service","url":"fluentci/envhub.html#with_service"},{"doc":"fluentci/envhub","title":"with_workdir","content":"pub fn with_workdir(envhub: Envhub, path: String) -&gt; Envhub\n\nSynonyms:\nfluentci/envhub.with_workdir\nfluentci/envhub with_workdir","url":"fluentci/envhub.html#with_workdir"},{"doc":"fluentci/envhub","title":"fluentci/envhub","content":"","url":"fluentci/envhub.html"},{"doc":"fluentci/pipeline","title":"Pipeline","content":"pub type Pipeline\n\n\nSynonyms:\nfluentci/pipeline.Pipeline\nfluentci/pipeline Pipeline","url":"fluentci/pipeline.html#Pipeline"},{"doc":"fluentci/pipeline","title":"as_service","content":"pub fn as_service(pipeline: Pipeline) -&gt; Service\n\nSynonyms:\nfluentci/pipeline.as_service\nfluentci/pipeline as_service","url":"fluentci/pipeline.html#as_service"},{"doc":"fluentci/pipeline","title":"devbox","content":"pub fn devbox(pipeline: Pipeline) -&gt; Devbox\n\nSynonyms:\nfluentci/pipeline.devbox\nfluentci/pipeline devbox","url":"fluentci/pipeline.html#devbox"},{"doc":"fluentci/pipeline","title":"devenv","content":"pub fn devenv(pipeline: Pipeline) -&gt; Devenv\n\nSynonyms:\nfluentci/pipeline.devenv\nfluentci/pipeline devenv","url":"fluentci/pipeline.html#devenv"},{"doc":"fluentci/pipeline","title":"envhub","content":"pub fn envhub(pipeline: Pipeline) -&gt; Envhub\n\nSynonyms:\nfluentci/pipeline.envhub\nfluentci/pipeline envhub","url":"fluentci/pipeline.html#envhub"},{"doc":"fluentci/pipeline","title":"id","content":"pub fn id(pipeline: Pipeline) -&gt; Promise(String)\n\nSynonyms:\nfluentci/pipeline.id\nfluentci/pipeline id","url":"fluentci/pipeline.html#id"},{"doc":"fluentci/pipeline","title":"mise","content":"pub fn mise(pipeline: Pipeline) -&gt; Mise\n\nSynonyms:\nfluentci/pipeline.mise\nfluentci/pipeline mise","url":"fluentci/pipeline.html#mise"},{"doc":"fluentci/pipeline","title":"nix","content":"pub fn nix(pipeline: Pipeline) -&gt; Nix\n\nSynonyms:\nfluentci/pipeline.nix\nfluentci/pipeline nix","url":"fluentci/pipeline.html#nix"},{"doc":"fluentci/pipeline","title":"pixi","content":"pub fn pixi(pipeline: Pipeline) -&gt; Pixi\n\nSynonyms:\nfluentci/pipeline.pixi\nfluentci/pipeline pixi","url":"fluentci/pipeline.html#pixi"},{"doc":"fluentci/pipeline","title":"pkgx","content":"pub fn pkgx(pipeline: Pipeline) -&gt; Pkgx\n\nSynonyms:\nfluentci/pipeline.pkgx\nfluentci/pipeline pkgx","url":"fluentci/pipeline.html#pkgx"},{"doc":"fluentci/pipeline","title":"stderr","content":"pub fn stderr(pipeline: Pipeline) -&gt; Promise(String)\n\nSynonyms:\nfluentci/pipeline.stderr\nfluentci/pipeline stderr","url":"fluentci/pipeline.html#stderr"},{"doc":"fluentci/pipeline","title":"stdout","content":"pub fn stdout(pipeline: Pipeline) -&gt; Promise(String)\n\nSynonyms:\nfluentci/pipeline.stdout\nfluentci/pipeline stdout","url":"fluentci/pipeline.html#stdout"},{"doc":"fluentci/pipeline","title":"wait_on","content":"pub fn wait_on(\n  pipeline: Pipeline,\n  port: a,\n  timeout: a,\n) -&gt; Pipeline\n\nSynonyms:\nfluentci/pipeline.wait_on\nfluentci/pipeline wait_on","url":"fluentci/pipeline.html#wait_on"},{"doc":"fluentci/pipeline","title":"with_cache","content":"pub fn with_cache(pipeline: Pipeline, cache: Cache) -&gt; Pipeline\n\nSynonyms:\nfluentci/pipeline.with_cache\nfluentci/pipeline with_cache","url":"fluentci/pipeline.html#with_cache"},{"doc":"fluentci/pipeline","title":"with_env_variable","content":"pub fn with_env_variable(\n  pipeline: Pipeline,\n  name: String,\n  value: String,\n) -&gt; Pipeline\n\nSynonyms:\nfluentci/pipeline.with_env_variable\nfluentci/pipeline with_env_variable","url":"fluentci/pipeline.html#with_env_variable"},{"doc":"fluentci/pipeline","title":"with_exec","content":"pub fn with_exec(\n  pipeline: Pipeline,\n  command: Array(String),\n) -&gt; Pipeline\n\nSynonyms:\nfluentci/pipeline.with_exec\nfluentci/pipeline with_exec","url":"fluentci/pipeline.html#with_exec"},{"doc":"fluentci/pipeline","title":"with_secret_variable","content":"pub fn with_secret_variable(\n  pipeline: Pipeline,\n  name: String,\n  secret: Secret,\n) -&gt; Pipeline\n\nSynonyms:\nfluentci/pipeline.with_secret_variable\nfluentci/pipeline with_secret_variable","url":"fluentci/pipeline.html#with_secret_variable"},{"doc":"fluentci/pipeline","title":"with_service","content":"pub fn with_service(\n  pipeline: Pipeline,\n  service: Service,\n) -&gt; Pipeline\n\nSynonyms:\nfluentci/pipeline.with_service\nfluentci/pipeline with_service","url":"fluentci/pipeline.html#with_service"},{"doc":"fluentci/pipeline","title":"with_workdir","content":"pub fn with_workdir(pipeline: Pipeline, path: String) -&gt; Pipeline\n\nSynonyms:\nfluentci/pipeline.with_workdir\nfluentci/pipeline with_workdir","url":"fluentci/pipeline.html#with_workdir"},{"doc":"fluentci/pipeline","title":"fluentci/pipeline","content":"","url":"fluentci/pipeline.html"},{"doc":"fluentci/secret_manager","title":"SecretManager","content":"pub type SecretManager\n\n\nSynonyms:\nfluentci/secret_manager.SecretManager\nfluentci/secret_manager SecretManager","url":"fluentci/secret_manager.html#SecretManager"},{"doc":"fluentci/secret_manager","title":"get_secret","content":"pub fn get_secret(\n  secret_manager: SecretManager,\n  name: String,\n) -&gt; Promise(Array(Secret))\n\nSynonyms:\nfluentci/secret_manager.get_secret\nfluentci/secret_manager get_secret","url":"fluentci/secret_manager.html#get_secret"},{"doc":"fluentci/secret_manager","title":"id","content":"pub fn id(secret_manager: SecretManager) -&gt; Promise(String)\n\nSynonyms:\nfluentci/secret_manager.id\nfluentci/secret_manager id","url":"fluentci/secret_manager.html#id"},{"doc":"fluentci/secret_manager","title":"fluentci/secret_manager","content":"","url":"fluentci/secret_manager.html"},{"doc":"fluentci","title":"Client","content":"pub type Client\n\n\nSynonyms:\nfluentci.Client\nfluentci Client","url":"fluentci.html#Client"},{"doc":"fluentci","title":"NixArgs","content":"pub type NixArgs {\n  NixArgs(impure: Bool)\n}\n\nNixArgs(impure: Bool)\n\n\nSynonyms:\nfluentci.NixArgs\nfluentci NixArgs","url":"fluentci.html#NixArgs"},{"doc":"fluentci","title":"azure_keyvault","content":"pub fn azure_keyvault(\n  client: Client,\n  client_id: String,\n  client_secret: String,\n  tenant_id: String,\n  keyvault_name: String,\n  keyvault_url: String,\n) -&gt; SecretManager\n\nSynonyms:\nfluentci.azure_keyvault\nfluentci azure_keyvault","url":"fluentci.html#azure_keyvault"},{"doc":"fluentci","title":"azure_secrets_manager","content":"pub fn azure_secrets_manager(\n  client: Client,\n  region: String,\n  access_key_id: String,\n  secret_access_key: String,\n) -&gt; SecretManager\n\nSynonyms:\nfluentci.azure_secrets_manager\nfluentci azure_secrets_manager","url":"fluentci.html#azure_secrets_manager"},{"doc":"fluentci","title":"cache","content":"pub fn cache(client: Client, key: String) -&gt; Cache\n\nSynonyms:\nfluentci.cache\nfluentci cache","url":"fluentci.html#cache"},{"doc":"fluentci","title":"dag","content":"pub fn dag() -&gt; Client\n\nSynonyms:\nfluentci.dag\nfluentci dag","url":"fluentci.html#dag"},{"doc":"fluentci","title":"devbox","content":"pub fn devbox(client: Client) -&gt; Devbox\n\nSynonyms:\nfluentci.devbox\nfluentci devbox","url":"fluentci.html#devbox"},{"doc":"fluentci","title":"devenv","content":"pub fn devenv(client: Client) -&gt; Devenv\n\nSynonyms:\nfluentci.devenv\nfluentci devenv","url":"fluentci.html#devenv"},{"doc":"fluentci","title":"directory","content":"pub fn directory(client: Client, path: String) -&gt; Directory\n\nSynonyms:\nfluentci.directory\nfluentci directory","url":"fluentci.html#directory"},{"doc":"fluentci","title":"file","content":"pub fn file(client: Client, path: String) -&gt; File\n\nSynonyms:\nfluentci.file\nfluentci file","url":"fluentci.html#file"},{"doc":"fluentci","title":"flox","content":"pub fn flox(client: Client) -&gt; Flox\n\nSynonyms:\nfluentci.flox\nfluentci flox","url":"fluentci.html#flox"},{"doc":"fluentci","title":"git","content":"pub fn git(client: Client, url: String) -&gt; Git\n\nSynonyms:\nfluentci.git\nfluentci git","url":"fluentci.html#git"},{"doc":"fluentci","title":"google_cloud_secret_manager","content":"pub fn google_cloud_secret_manager(\n  client: Client,\n  project: String,\n  google_credentials_file: String,\n) -&gt; SecretManager\n\nSynonyms:\nfluentci.google_cloud_secret_manager\nfluentci google_cloud_secret_manager","url":"fluentci.html#google_cloud_secret_manager"},{"doc":"fluentci","title":"hashicorp_vault","content":"pub fn hashicorp_vault(\n  client: Client,\n  address: String,\n  token: String,\n  cacerts: String,\n) -&gt; SecretManager\n\nSynonyms:\nfluentci.hashicorp_vault\nfluentci hashicorp_vault","url":"fluentci.html#hashicorp_vault"},{"doc":"fluentci","title":"http","content":"pub fn http(client: Client, url: String) -&gt; File\n\nSynonyms:\nfluentci.http\nfluentci http","url":"fluentci.html#http"},{"doc":"fluentci","title":"mise","content":"pub fn mise(client: Client) -&gt; Mise\n\nSynonyms:\nfluentci.mise\nfluentci mise","url":"fluentci.html#mise"},{"doc":"fluentci","title":"nix","content":"pub fn nix(client: Client, args: NixArgs) -&gt; Nix\n\nSynonyms:\nfluentci.nix\nfluentci nix","url":"fluentci.html#nix"},{"doc":"fluentci","title":"pipeline","content":"pub fn pipeline(client: Client, name: String) -&gt; Pipeline\n\nSynonyms:\nfluentci.pipeline\nfluentci pipeline","url":"fluentci.html#pipeline"},{"doc":"fluentci","title":"pixi","content":"pub fn pixi(client: Client) -&gt; Pixi\n\nSynonyms:\nfluentci.pixi\nfluentci pixi","url":"fluentci.html#pixi"},{"doc":"fluentci","title":"pkgx","content":"pub fn pkgx(client: Client) -&gt; Pkgx\n\nSynonyms:\nfluentci.pkgx\nfluentci pkgx","url":"fluentci.html#pkgx"},{"doc":"fluentci","title":"set_secret","content":"pub fn set_secret(\n  client: Client,\n  name: String,\n  value: String,\n) -&gt; Secret\n\nSynonyms:\nfluentci.set_secret\nfluentci set_secret","url":"fluentci.html#set_secret"},{"doc":"fluentci","title":"fluentci","content":"","url":"fluentci.html"},{"doc":"fluentci/dagger/cache_volume","title":"CacheVolume","content":"pub type CacheVolume\n\n\nSynonyms:\nfluentci/dagger/cache_volume.CacheVolume\nfluentci/dagger/cache_volume CacheVolume","url":"fluentci/dagger/cache_volume.html#CacheVolume"},{"doc":"fluentci/dagger/cache_volume","title":"id","content":"pub fn id(cache_volume: CacheVolume) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/cache_volume.id\nfluentci/dagger/cache_volume id","url":"fluentci/dagger/cache_volume.html#id"},{"doc":"fluentci/dagger/cache_volume","title":"fluentci/dagger/cache_volume","content":"","url":"fluentci/dagger/cache_volume.html"},{"doc":"fluentci/dagger/container","title":"Container","content":"pub type Container\n\n\nSynonyms:\nfluentci/dagger/container.Container\nfluentci/dagger/container Container","url":"fluentci/dagger/container.html#Container"},{"doc":"fluentci/dagger/container","title":"from","content":"pub fn from(container: Container, image: String) -&gt; Container\n\nSynonyms:\nfluentci/dagger/container.from\nfluentci/dagger/container from","url":"fluentci/dagger/container.html#from"},{"doc":"fluentci/dagger/container","title":"id","content":"pub fn id(container: Container) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/container.id\nfluentci/dagger/container id","url":"fluentci/dagger/container.html#id"},{"doc":"fluentci/dagger/container","title":"stderr","content":"pub fn stderr(container: Container) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/container.stderr\nfluentci/dagger/container stderr","url":"fluentci/dagger/container.html#stderr"},{"doc":"fluentci/dagger/container","title":"stdout","content":"pub fn stdout(container: Container) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/container.stdout\nfluentci/dagger/container stdout","url":"fluentci/dagger/container.html#stdout"},{"doc":"fluentci/dagger/container","title":"with_exec","content":"pub fn with_exec(\n  container: Container,\n  args: Array(String),\n) -&gt; Container\n\nSynonyms:\nfluentci/dagger/container.with_exec\nfluentci/dagger/container with_exec","url":"fluentci/dagger/container.html#with_exec"},{"doc":"fluentci/dagger/container","title":"fluentci/dagger/container","content":"","url":"fluentci/dagger/container.html"},{"doc":"fluentci/dagger/file","title":"File","content":"pub type File\n\n\nSynonyms:\nfluentci/dagger/file.File\nfluentci/dagger/file File","url":"fluentci/dagger/file.html#File"},{"doc":"fluentci/dagger/file","title":"contents","content":"pub fn contents(file: File) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/file.contents\nfluentci/dagger/file contents","url":"fluentci/dagger/file.html#contents"},{"doc":"fluentci/dagger/file","title":"digest","content":"pub fn digest(file: File) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/file.digest\nfluentci/dagger/file digest","url":"fluentci/dagger/file.html#digest"},{"doc":"fluentci/dagger/file","title":"export","content":"pub fn export(file: File, path: String) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/file.export\nfluentci/dagger/file export","url":"fluentci/dagger/file.html#export"},{"doc":"fluentci/dagger/file","title":"id","content":"pub fn id(file: File) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/file.id\nfluentci/dagger/file id","url":"fluentci/dagger/file.html#id"},{"doc":"fluentci/dagger/file","title":"name","content":"pub fn name(file: File) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/file.name\nfluentci/dagger/file name","url":"fluentci/dagger/file.html#name"},{"doc":"fluentci/dagger/file","title":"size","content":"pub fn size(file: File) -&gt; Promise(Int)\n\nSynonyms:\nfluentci/dagger/file.size\nfluentci/dagger/file size","url":"fluentci/dagger/file.html#size"},{"doc":"fluentci/dagger/file","title":"sync","content":"pub fn sync(file: File) -&gt; Promise(File)\n\nSynonyms:\nfluentci/dagger/file.sync\nfluentci/dagger/file sync","url":"fluentci/dagger/file.html#sync"},{"doc":"fluentci/dagger/file","title":"with_name","content":"pub fn with_name(file: File, name: String) -&gt; File\n\nSynonyms:\nfluentci/dagger/file.with_name\nfluentci/dagger/file with_name","url":"fluentci/dagger/file.html#with_name"},{"doc":"fluentci/dagger/file","title":"with_timestamps","content":"pub fn with_timestamps(file: File, timestamp: Int) -&gt; File\n\nSynonyms:\nfluentci/dagger/file.with_timestamps\nfluentci/dagger/file with_timestamps","url":"fluentci/dagger/file.html#with_timestamps"},{"doc":"fluentci/dagger/file","title":"fluentci/dagger/file","content":"","url":"fluentci/dagger/file.html"},{"doc":"fluentci/dagger/module","title":"Module","content":"pub type Module\n\n\nSynonyms:\nfluentci/dagger/module.Module\nfluentci/dagger/module Module","url":"fluentci/dagger/module.html#Module"},{"doc":"fluentci/dagger/module","title":"ModuleDependency","content":"pub type ModuleDependency\n\n\nSynonyms:\nfluentci/dagger/module.ModuleDependency\nfluentci/dagger/module ModuleDependency","url":"fluentci/dagger/module.html#ModuleDependency"},{"doc":"fluentci/dagger/module","title":"ModuleSource","content":"pub type ModuleSource\n\n\nSynonyms:\nfluentci/dagger/module.ModuleSource\nfluentci/dagger/module ModuleSource","url":"fluentci/dagger/module.html#ModuleSource"},{"doc":"fluentci/dagger/module","title":"ModuleSourceView","content":"pub type ModuleSourceView\n\n\nSynonyms:\nfluentci/dagger/module.ModuleSourceView\nfluentci/dagger/module ModuleSourceView","url":"fluentci/dagger/module.html#ModuleSourceView"},{"doc":"fluentci/dagger/module","title":"dependencies","content":"pub fn dependencies(module: Module) -&gt; Promise(Array(Module))\n\nSynonyms:\nfluentci/dagger/module.dependencies\nfluentci/dagger/module dependencies","url":"fluentci/dagger/module.html#dependencies"},{"doc":"fluentci/dagger/module","title":"dependency_config","content":"pub fn dependency_config(\n  module: Module,\n) -&gt; Promise(Array(ModuleDependency))\n\nSynonyms:\nfluentci/dagger/module.dependency_config\nfluentci/dagger/module dependency_config","url":"fluentci/dagger/module.html#dependency_config"},{"doc":"fluentci/dagger/module","title":"id","content":"pub fn id(module: Module) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module.id\nfluentci/dagger/module id","url":"fluentci/dagger/module.html#id"},{"doc":"fluentci/dagger/module","title":"fluentci/dagger/module","content":"","url":"fluentci/dagger/module.html"},{"doc":"fluentci/dagger/directory","title":"Directory","content":"pub type Directory\n\n\nSynonyms:\nfluentci/dagger/directory.Directory\nfluentci/dagger/directory Directory","url":"fluentci/dagger/directory.html#Directory"},{"doc":"fluentci/dagger/directory","title":"as_module","content":"pub fn as_module(directory: Directory) -&gt; Module\n\nSynonyms:\nfluentci/dagger/directory.as_module\nfluentci/dagger/directory as_module","url":"fluentci/dagger/directory.html#as_module"},{"doc":"fluentci/dagger/directory","title":"diff","content":"pub fn diff(directory: Directory, other: Directory) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.diff\nfluentci/dagger/directory diff","url":"fluentci/dagger/directory.html#diff"},{"doc":"fluentci/dagger/directory","title":"directory","content":"pub fn directory(d: Directory, path: String) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.directory\nfluentci/dagger/directory directory","url":"fluentci/dagger/directory.html#directory"},{"doc":"fluentci/dagger/directory","title":"docker_build","content":"pub fn docker_build(directory: Directory) -&gt; Container\n\nSynonyms:\nfluentci/dagger/directory.docker_build\nfluentci/dagger/directory docker_build","url":"fluentci/dagger/directory.html#docker_build"},{"doc":"fluentci/dagger/directory","title":"entries","content":"pub fn entries(directory: Directory) -&gt; Promise(Array(String))\n\nSynonyms:\nfluentci/dagger/directory.entries\nfluentci/dagger/directory entries","url":"fluentci/dagger/directory.html#entries"},{"doc":"fluentci/dagger/directory","title":"export","content":"pub fn export(\n  directory: Directory,\n  path: String,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/directory.export\nfluentci/dagger/directory export","url":"fluentci/dagger/directory.html#export"},{"doc":"fluentci/dagger/directory","title":"file","content":"pub fn file(directory: Directory, path: String) -&gt; File\n\nSynonyms:\nfluentci/dagger/directory.file\nfluentci/dagger/directory file","url":"fluentci/dagger/directory.html#file"},{"doc":"fluentci/dagger/directory","title":"glob","content":"pub fn glob(\n  directory: Directory,\n  pattern: String,\n) -&gt; Promise(Array(String))\n\nSynonyms:\nfluentci/dagger/directory.glob\nfluentci/dagger/directory glob","url":"fluentci/dagger/directory.html#glob"},{"doc":"fluentci/dagger/directory","title":"id","content":"pub fn id(directory: Directory) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/directory.id\nfluentci/dagger/directory id","url":"fluentci/dagger/directory.html#id"},{"doc":"fluentci/dagger/directory","title":"pipeline","content":"pub fn pipeline(directory: Directory, name: String) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.pipeline\nfluentci/dagger/directory pipeline","url":"fluentci/dagger/directory.html#pipeline"},{"doc":"fluentci/dagger/directory","title":"sync","content":"pub fn sync(directory: Directory) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.sync\nfluentci/dagger/directory sync","url":"fluentci/dagger/directory.html#sync"},{"doc":"fluentci/dagger/directory","title":"terminal","content":"pub fn terminal(directory: Directory) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.terminal\nfluentci/dagger/directory terminal","url":"fluentci/dagger/directory.html#terminal"},{"doc":"fluentci/dagger/directory","title":"with_directory","content":"pub fn with_directory(\n  d: Directory,\n  path: String,\n  directory: Directory,\n) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.with_directory\nfluentci/dagger/directory with_directory","url":"fluentci/dagger/directory.html#with_directory"},{"doc":"fluentci/dagger/directory","title":"with_file","content":"pub fn with_file(d: Directory, source: File) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.with_file\nfluentci/dagger/directory with_file","url":"fluentci/dagger/directory.html#with_file"},{"doc":"fluentci/dagger/directory","title":"with_files","content":"pub fn with_files(\n  d: Directory,\n  sources: Array(File),\n) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.with_files\nfluentci/dagger/directory with_files","url":"fluentci/dagger/directory.html#with_files"},{"doc":"fluentci/dagger/directory","title":"with_new_directory","content":"pub fn with_new_directory(\n  d: Directory,\n  path: String,\n) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.with_new_directory\nfluentci/dagger/directory with_new_directory","url":"fluentci/dagger/directory.html#with_new_directory"},{"doc":"fluentci/dagger/directory","title":"with_new_file","content":"pub fn with_new_file(\n  d: Directory,\n  path: String,\n  contents: String,\n) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.with_new_file\nfluentci/dagger/directory with_new_file","url":"fluentci/dagger/directory.html#with_new_file"},{"doc":"fluentci/dagger/directory","title":"with_timestamps","content":"pub fn with_timestamps(d: Directory, timestamp: Int) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.with_timestamps\nfluentci/dagger/directory with_timestamps","url":"fluentci/dagger/directory.html#with_timestamps"},{"doc":"fluentci/dagger/directory","title":"without_directory","content":"pub fn without_directory(d: Directory, path: String) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.without_directory\nfluentci/dagger/directory without_directory","url":"fluentci/dagger/directory.html#without_directory"},{"doc":"fluentci/dagger/directory","title":"without_file","content":"pub fn without_file(d: Directory, path: String) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/directory.without_file\nfluentci/dagger/directory without_file","url":"fluentci/dagger/directory.html#without_file"},{"doc":"fluentci/dagger/directory","title":"fluentci/dagger/directory","content":"","url":"fluentci/dagger/directory.html"},{"doc":"fluentci/dagger/git_ref","title":"GitRef","content":"pub type GitRef\n\n\nSynonyms:\nfluentci/dagger/git_ref.GitRef\nfluentci/dagger/git_ref GitRef","url":"fluentci/dagger/git_ref.html#GitRef"},{"doc":"fluentci/dagger/git_ref","title":"commit","content":"pub fn commit(git_ref: GitRef) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/git_ref.commit\nfluentci/dagger/git_ref commit","url":"fluentci/dagger/git_ref.html#commit"},{"doc":"fluentci/dagger/git_ref","title":"id","content":"pub fn id(git_ref: GitRef) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/git_ref.id\nfluentci/dagger/git_ref id","url":"fluentci/dagger/git_ref.html#id"},{"doc":"fluentci/dagger/git_ref","title":"tree","content":"pub fn tree(git_ref: GitRef) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/git_ref.tree\nfluentci/dagger/git_ref tree","url":"fluentci/dagger/git_ref.html#tree"},{"doc":"fluentci/dagger/git_ref","title":"fluentci/dagger/git_ref","content":"","url":"fluentci/dagger/git_ref.html"},{"doc":"fluentci/dagger/secret","title":"Secret","content":"pub type Secret\n\n\nSynonyms:\nfluentci/dagger/secret.Secret\nfluentci/dagger/secret Secret","url":"fluentci/dagger/secret.html#Secret"},{"doc":"fluentci/dagger/secret","title":"id","content":"pub fn id(secret: Secret) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/secret.id\nfluentci/dagger/secret id","url":"fluentci/dagger/secret.html#id"},{"doc":"fluentci/dagger/secret","title":"name","content":"pub fn name(secret: Secret) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/secret.name\nfluentci/dagger/secret name","url":"fluentci/dagger/secret.html#name"},{"doc":"fluentci/dagger/secret","title":"plaintext","content":"pub fn plaintext(secret: Secret) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/secret.plaintext\nfluentci/dagger/secret plaintext","url":"fluentci/dagger/secret.html#plaintext"},{"doc":"fluentci/dagger/secret","title":"fluentci/dagger/secret","content":"","url":"fluentci/dagger/secret.html"},{"doc":"fluentci/dagger/git","title":"GitRepository","content":"pub type GitRepository\n\n\nSynonyms:\nfluentci/dagger/git.GitRepository\nfluentci/dagger/git GitRepository","url":"fluentci/dagger/git.html#GitRepository"},{"doc":"fluentci/dagger/git","title":"branch","content":"pub fn branch(git: GitRepository, name: String) -&gt; GitRef\n\nSynonyms:\nfluentci/dagger/git.branch\nfluentci/dagger/git branch","url":"fluentci/dagger/git.html#branch"},{"doc":"fluentci/dagger/git","title":"commit","content":"pub fn commit(git: GitRepository, id: String) -&gt; GitRef\n\nSynonyms:\nfluentci/dagger/git.commit\nfluentci/dagger/git commit","url":"fluentci/dagger/git.html#commit"},{"doc":"fluentci/dagger/git","title":"head","content":"pub fn head(git: GitRepository) -&gt; GitRef\n\nSynonyms:\nfluentci/dagger/git.head\nfluentci/dagger/git head","url":"fluentci/dagger/git.html#head"},{"doc":"fluentci/dagger/git","title":"id","content":"pub fn id(git: GitRepository) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/git.id\nfluentci/dagger/git id","url":"fluentci/dagger/git.html#id"},{"doc":"fluentci/dagger/git","title":"ref","content":"pub fn ref(git: GitRepository, name: String) -&gt; GitRef\n\nSynonyms:\nfluentci/dagger/git.ref\nfluentci/dagger/git ref","url":"fluentci/dagger/git.html#ref"},{"doc":"fluentci/dagger/git","title":"tag","content":"pub fn tag(git: GitRepository, name: String) -&gt; GitRef\n\nSynonyms:\nfluentci/dagger/git.tag\nfluentci/dagger/git tag","url":"fluentci/dagger/git.html#tag"},{"doc":"fluentci/dagger/git","title":"tags","content":"pub fn tags(git: GitRepository) -&gt; Array(String)\n\nSynonyms:\nfluentci/dagger/git.tags\nfluentci/dagger/git tags","url":"fluentci/dagger/git.html#tags"},{"doc":"fluentci/dagger/git","title":"with_auth_header","content":"pub fn with_auth_header(\n  git: GitRepository,\n  header: Secret,\n) -&gt; GitRepository\n\nSynonyms:\nfluentci/dagger/git.with_auth_header\nfluentci/dagger/git with_auth_header","url":"fluentci/dagger/git.html#with_auth_header"},{"doc":"fluentci/dagger/git","title":"with_auth_token","content":"pub fn with_auth_token(\n  git: GitRepository,\n  token: Secret,\n) -&gt; GitRepository\n\nSynonyms:\nfluentci/dagger/git.with_auth_token\nfluentci/dagger/git with_auth_token","url":"fluentci/dagger/git.html#with_auth_token"},{"doc":"fluentci/dagger/git","title":"fluentci/dagger/git","content":"","url":"fluentci/dagger/git.html"},{"doc":"fluentci/dagger/port","title":"Port","content":"pub type Port\n\n\nSynonyms:\nfluentci/dagger/port.Port\nfluentci/dagger/port Port","url":"fluentci/dagger/port.html#Port"},{"doc":"fluentci/dagger/port","title":"description","content":"pub fn description(port: Port) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/port.description\nfluentci/dagger/port description","url":"fluentci/dagger/port.html#description"},{"doc":"fluentci/dagger/port","title":"experimental_skip_healthcheck","content":"pub fn experimental_skip_healthcheck(port: Port) -&gt; Promise(Bool)\n\nSynonyms:\nfluentci/dagger/port.experimental_skip_healthcheck\nfluentci/dagger/port experimental_skip_healthcheck","url":"fluentci/dagger/port.html#experimental_skip_healthcheck"},{"doc":"fluentci/dagger/port","title":"id","content":"pub fn id(port: Port) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/port.id\nfluentci/dagger/port id","url":"fluentci/dagger/port.html#id"},{"doc":"fluentci/dagger/port","title":"port","content":"pub fn port(port: Port) -&gt; Promise(Int)\n\nSynonyms:\nfluentci/dagger/port.port\nfluentci/dagger/port port","url":"fluentci/dagger/port.html#port"},{"doc":"fluentci/dagger/port","title":"protocol","content":"pub fn protocol(port: Port) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/port.protocol\nfluentci/dagger/port protocol","url":"fluentci/dagger/port.html#protocol"},{"doc":"fluentci/dagger/port","title":"fluentci/dagger/port","content":"","url":"fluentci/dagger/port.html"},{"doc":"fluentci/dagger/void","title":"Void","content":"pub type Void\n\n\nSynonyms:\nfluentci/dagger/void.Void\nfluentci/dagger/void Void","url":"fluentci/dagger/void.html#Void"},{"doc":"fluentci/dagger/void","title":"fluentci/dagger/void","content":"","url":"fluentci/dagger/void.html"},{"doc":"fluentci/dagger/service","title":"Service","content":"pub type Service\n\n\nSynonyms:\nfluentci/dagger/service.Service\nfluentci/dagger/service Service","url":"fluentci/dagger/service.html#Service"},{"doc":"fluentci/dagger/service","title":"endpoint","content":"pub fn endpoint(service: Service) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/service.endpoint\nfluentci/dagger/service endpoint","url":"fluentci/dagger/service.html#endpoint"},{"doc":"fluentci/dagger/service","title":"hostname","content":"pub fn hostname(service: Service) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/service.hostname\nfluentci/dagger/service hostname","url":"fluentci/dagger/service.html#hostname"},{"doc":"fluentci/dagger/service","title":"id","content":"pub fn id(service: Service) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/service.id\nfluentci/dagger/service id","url":"fluentci/dagger/service.html#id"},{"doc":"fluentci/dagger/service","title":"ports","content":"pub fn ports(service: Service) -&gt; Promise(Array(Port))\n\nSynonyms:\nfluentci/dagger/service.ports\nfluentci/dagger/service ports","url":"fluentci/dagger/service.html#ports"},{"doc":"fluentci/dagger/service","title":"start","content":"pub fn start(service: Service) -&gt; Promise(Service)\n\nSynonyms:\nfluentci/dagger/service.start\nfluentci/dagger/service start","url":"fluentci/dagger/service.html#start"},{"doc":"fluentci/dagger/service","title":"stop","content":"pub fn stop(service: Service) -&gt; Promise(Service)\n\nSynonyms:\nfluentci/dagger/service.stop\nfluentci/dagger/service stop","url":"fluentci/dagger/service.html#stop"},{"doc":"fluentci/dagger/service","title":"up","content":"pub fn up(service: Service) -&gt; Promise(Void)\n\nSynonyms:\nfluentci/dagger/service.up\nfluentci/dagger/service up","url":"fluentci/dagger/service.html#up"},{"doc":"fluentci/dagger/service","title":"fluentci/dagger/service","content":"","url":"fluentci/dagger/service.html"},{"doc":"fluentci/dagger/socket","title":"Socket","content":"pub type Socket\n\n\nSynonyms:\nfluentci/dagger/socket.Socket\nfluentci/dagger/socket Socket","url":"fluentci/dagger/socket.html#Socket"},{"doc":"fluentci/dagger/socket","title":"id","content":"pub fn id(socket: Socket) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/socket.id\nfluentci/dagger/socket id","url":"fluentci/dagger/socket.html#id"},{"doc":"fluentci/dagger/socket","title":"fluentci/dagger/socket","content":"","url":"fluentci/dagger/socket.html"},{"doc":"fluentci/dagger/host","title":"Host","content":"pub type Host\n\n\nSynonyms:\nfluentci/dagger/host.Host\nfluentci/dagger/host Host","url":"fluentci/dagger/host.html#Host"},{"doc":"fluentci/dagger/host","title":"directory","content":"pub fn directory(host: Host, path: String) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/host.directory\nfluentci/dagger/host directory","url":"fluentci/dagger/host.html#directory"},{"doc":"fluentci/dagger/host","title":"file","content":"pub fn file(host: Host, path: String) -&gt; File\n\nSynonyms:\nfluentci/dagger/host.file\nfluentci/dagger/host file","url":"fluentci/dagger/host.html#file"},{"doc":"fluentci/dagger/host","title":"id","content":"pub fn id(host: Host) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/host.id\nfluentci/dagger/host id","url":"fluentci/dagger/host.html#id"},{"doc":"fluentci/dagger/host","title":"service","content":"pub fn service(host: Host) -&gt; Service\n\nSynonyms:\nfluentci/dagger/host.service\nfluentci/dagger/host service","url":"fluentci/dagger/host.html#service"},{"doc":"fluentci/dagger/host","title":"set_secret_file","content":"pub fn set_secret_file(\n  host: Host,\n  name: String,\n  path: String,\n) -&gt; Secret\n\nSynonyms:\nfluentci/dagger/host.set_secret_file\nfluentci/dagger/host set_secret_file","url":"fluentci/dagger/host.html#set_secret_file"},{"doc":"fluentci/dagger/host","title":"tunnel","content":"pub fn tunnel(host: Host, service: Service) -&gt; Service\n\nSynonyms:\nfluentci/dagger/host.tunnel\nfluentci/dagger/host tunnel","url":"fluentci/dagger/host.html#tunnel"},{"doc":"fluentci/dagger/host","title":"unix_socket","content":"pub fn unix_socket(host: Host, path: String) -&gt; Socket\n\nSynonyms:\nfluentci/dagger/host.unix_socket\nfluentci/dagger/host unix_socket","url":"fluentci/dagger/host.html#unix_socket"},{"doc":"fluentci/dagger/host","title":"fluentci/dagger/host","content":"","url":"fluentci/dagger/host.html"},{"doc":"fluentci/dagger/client","title":"Client","content":"pub type Client\n\n\nSynonyms:\nfluentci/dagger/client.Client\nfluentci/dagger/client Client","url":"fluentci/dagger/client.html#Client"},{"doc":"fluentci/dagger/client","title":"cache_volume","content":"pub fn cache_volume(client: Client, key: String) -&gt; CacheVolume\n\nSynonyms:\nfluentci/dagger/client.cache_volume\nfluentci/dagger/client cache_volume","url":"fluentci/dagger/client.html#cache_volume"},{"doc":"fluentci/dagger/client","title":"container","content":"pub fn container(client: Client) -&gt; Container\n\nSynonyms:\nfluentci/dagger/client.container\nfluentci/dagger/client container","url":"fluentci/dagger/client.html#container"},{"doc":"fluentci/dagger/client","title":"dag","content":"pub fn dag() -&gt; Client\n\nSynonyms:\nfluentci/dagger/client.dag\nfluentci/dagger/client dag","url":"fluentci/dagger/client.html#dag"},{"doc":"fluentci/dagger/client","title":"directory","content":"pub fn directory(client: Client) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/client.directory\nfluentci/dagger/client directory","url":"fluentci/dagger/client.html#directory"},{"doc":"fluentci/dagger/client","title":"git","content":"pub fn git(client: Client, url: String) -&gt; GitRepository\n\nSynonyms:\nfluentci/dagger/client.git\nfluentci/dagger/client git","url":"fluentci/dagger/client.html#git"},{"doc":"fluentci/dagger/client","title":"host","content":"pub fn host(client: Client) -&gt; Host\n\nSynonyms:\nfluentci/dagger/client.host\nfluentci/dagger/client host","url":"fluentci/dagger/client.html#host"},{"doc":"fluentci/dagger/client","title":"http","content":"pub fn http(client: Client, url: String) -&gt; File\n\nSynonyms:\nfluentci/dagger/client.http\nfluentci/dagger/client http","url":"fluentci/dagger/client.html#http"},{"doc":"fluentci/dagger/client","title":"pipeline","content":"pub fn pipeline(client: Client, name: String) -&gt; Client\n\nSynonyms:\nfluentci/dagger/client.pipeline\nfluentci/dagger/client pipeline","url":"fluentci/dagger/client.html#pipeline"},{"doc":"fluentci/dagger/client","title":"fluentci/dagger/client","content":"","url":"fluentci/dagger/client.html"},{"doc":"fluentci/dagger/enum_value_type_def","title":"EnumValueTypeDef","content":"pub type EnumValueTypeDef\n\n\nSynonyms:\nfluentci/dagger/enum_value_type_def.EnumValueTypeDef\nfluentci/dagger/enum_value_type_def EnumValueTypeDef","url":"fluentci/dagger/enum_value_type_def.html#EnumValueTypeDef"},{"doc":"fluentci/dagger/enum_value_type_def","title":"description","content":"pub fn description(f: EnumValueTypeDef) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/enum_value_type_def.description\nfluentci/dagger/enum_value_type_def description","url":"fluentci/dagger/enum_value_type_def.html#description"},{"doc":"fluentci/dagger/enum_value_type_def","title":"id","content":"pub fn id(f: EnumValueTypeDef) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/enum_value_type_def.id\nfluentci/dagger/enum_value_type_def id","url":"fluentci/dagger/enum_value_type_def.html#id"},{"doc":"fluentci/dagger/enum_value_type_def","title":"name","content":"pub fn name(f: EnumValueTypeDef) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/enum_value_type_def.name\nfluentci/dagger/enum_value_type_def name","url":"fluentci/dagger/enum_value_type_def.html#name"},{"doc":"fluentci/dagger/enum_value_type_def","title":"fluentci/dagger/enum_value_type_def","content":"","url":"fluentci/dagger/enum_value_type_def.html"},{"doc":"fluentci/dagger/enum_type_def","title":"EnumTypeDef","content":"pub type EnumTypeDef\n\n\nSynonyms:\nfluentci/dagger/enum_type_def.EnumTypeDef\nfluentci/dagger/enum_type_def EnumTypeDef","url":"fluentci/dagger/enum_type_def.html#EnumTypeDef"},{"doc":"fluentci/dagger/enum_type_def","title":"description","content":"pub fn description(f: EnumTypeDef) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/enum_type_def.description\nfluentci/dagger/enum_type_def description","url":"fluentci/dagger/enum_type_def.html#description"},{"doc":"fluentci/dagger/enum_type_def","title":"id","content":"pub fn id(f: EnumTypeDef) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/enum_type_def.id\nfluentci/dagger/enum_type_def id","url":"fluentci/dagger/enum_type_def.html#id"},{"doc":"fluentci/dagger/enum_type_def","title":"name","content":"pub fn name(f: EnumTypeDef) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/enum_type_def.name\nfluentci/dagger/enum_type_def name","url":"fluentci/dagger/enum_type_def.html#name"},{"doc":"fluentci/dagger/enum_type_def","title":"source_module_name","content":"pub fn source_module_name(f: EnumTypeDef) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/enum_type_def.source_module_name\nfluentci/dagger/enum_type_def source_module_name","url":"fluentci/dagger/enum_type_def.html#source_module_name"},{"doc":"fluentci/dagger/enum_type_def","title":"values","content":"pub fn values(f: EnumTypeDef) -&gt; Promise(Array(EnumValueTypeDef))\n\nSynonyms:\nfluentci/dagger/enum_type_def.values\nfluentci/dagger/enum_type_def values","url":"fluentci/dagger/enum_type_def.html#values"},{"doc":"fluentci/dagger/enum_type_def","title":"fluentci/dagger/enum_type_def","content":"","url":"fluentci/dagger/enum_type_def.html"},{"doc":"fluentci/dagger/env_variable","title":"EnvVariable","content":"pub type EnvVariable\n\n\nSynonyms:\nfluentci/dagger/env_variable.EnvVariable\nfluentci/dagger/env_variable EnvVariable","url":"fluentci/dagger/env_variable.html#EnvVariable"},{"doc":"fluentci/dagger/env_variable","title":"id","content":"pub fn id(env_variable: EnvVariable) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/env_variable.id\nfluentci/dagger/env_variable id","url":"fluentci/dagger/env_variable.html#id"},{"doc":"fluentci/dagger/env_variable","title":"name","content":"pub fn name(env_variable: EnvVariable) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/env_variable.name\nfluentci/dagger/env_variable name","url":"fluentci/dagger/env_variable.html#name"},{"doc":"fluentci/dagger/env_variable","title":"value","content":"pub fn value(env_variable: EnvVariable) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/env_variable.value\nfluentci/dagger/env_variable value","url":"fluentci/dagger/env_variable.html#value"},{"doc":"fluentci/dagger/env_variable","title":"fluentci/dagger/env_variable","content":"","url":"fluentci/dagger/env_variable.html"},{"doc":"fluentci/dagger/function_arg","title":"FunctionArg","content":"pub type FunctionArg\n\n\nSynonyms:\nfluentci/dagger/function_arg.FunctionArg\nfluentci/dagger/function_arg FunctionArg","url":"fluentci/dagger/function_arg.html#FunctionArg"},{"doc":"fluentci/dagger/function_arg","title":"JSON","content":"pub type JSON\n\n\nSynonyms:\nfluentci/dagger/function_arg.JSON\nfluentci/dagger/function_arg JSON","url":"fluentci/dagger/function_arg.html#JSON"},{"doc":"fluentci/dagger/function_arg","title":"default_value","content":"pub fn default_value(f: FunctionArg) -&gt; Promise(JSON)\n\nSynonyms:\nfluentci/dagger/function_arg.default_value\nfluentci/dagger/function_arg default_value","url":"fluentci/dagger/function_arg.html#default_value"},{"doc":"fluentci/dagger/function_arg","title":"description","content":"pub fn description(f: FunctionArg) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function_arg.description\nfluentci/dagger/function_arg description","url":"fluentci/dagger/function_arg.html#description"},{"doc":"fluentci/dagger/function_arg","title":"id","content":"pub fn id(f: FunctionArg) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function_arg.id\nfluentci/dagger/function_arg id","url":"fluentci/dagger/function_arg.html#id"},{"doc":"fluentci/dagger/function_arg","title":"name","content":"pub fn name(f: FunctionArg) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function_arg.name\nfluentci/dagger/function_arg name","url":"fluentci/dagger/function_arg.html#name"},{"doc":"fluentci/dagger/function_arg","title":"type_def","content":"pub fn type_def(f: FunctionArg) -&gt; Promise(JSON)\n\nSynonyms:\nfluentci/dagger/function_arg.type_def\nfluentci/dagger/function_arg type_def","url":"fluentci/dagger/function_arg.html#type_def"},{"doc":"fluentci/dagger/function_arg","title":"fluentci/dagger/function_arg","content":"","url":"fluentci/dagger/function_arg.html"},{"doc":"fluentci/dagger/type_def","title":"TypeDef","content":"pub type TypeDef\n\n\nSynonyms:\nfluentci/dagger/type_def.TypeDef\nfluentci/dagger/type_def TypeDef","url":"fluentci/dagger/type_def.html#TypeDef"},{"doc":"fluentci/dagger/type_def","title":"as_enum","content":"pub fn as_enum(t: TypeDef) -&gt; EnumTypeDef\n\nSynonyms:\nfluentci/dagger/type_def.as_enum\nfluentci/dagger/type_def as_enum","url":"fluentci/dagger/type_def.html#as_enum"},{"doc":"fluentci/dagger/type_def","title":"id","content":"pub fn id(t: TypeDef) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/type_def.id\nfluentci/dagger/type_def id","url":"fluentci/dagger/type_def.html#id"},{"doc":"fluentci/dagger/type_def","title":"fluentci/dagger/type_def","content":"","url":"fluentci/dagger/type_def.html"},{"doc":"fluentci/dagger/function","title":"Function","content":"pub type Function\n\n\nSynonyms:\nfluentci/dagger/function.Function\nfluentci/dagger/function Function","url":"fluentci/dagger/function.html#Function"},{"doc":"fluentci/dagger/function","title":"args","content":"pub fn args(f: Function) -&gt; Promise(Array(FunctionArg))\n\nSynonyms:\nfluentci/dagger/function.args\nfluentci/dagger/function args","url":"fluentci/dagger/function.html#args"},{"doc":"fluentci/dagger/function","title":"description","content":"pub fn description(f: Function) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function.description\nfluentci/dagger/function description","url":"fluentci/dagger/function.html#description"},{"doc":"fluentci/dagger/function","title":"id","content":"pub fn id(f: Function) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function.id\nfluentci/dagger/function id","url":"fluentci/dagger/function.html#id"},{"doc":"fluentci/dagger/function","title":"name","content":"pub fn name(f: Function) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function.name\nfluentci/dagger/function name","url":"fluentci/dagger/function.html#name"},{"doc":"fluentci/dagger/function","title":"return_type","content":"pub fn return_type(f: Function) -&gt; TypeDef\n\nSynonyms:\nfluentci/dagger/function.return_type\nfluentci/dagger/function return_type","url":"fluentci/dagger/function.html#return_type"},{"doc":"fluentci/dagger/function","title":"with_arg","content":"pub fn with_arg(f: Function, arg: FunctionArg) -&gt; Function\n\nSynonyms:\nfluentci/dagger/function.with_arg\nfluentci/dagger/function with_arg","url":"fluentci/dagger/function.html#with_arg"},{"doc":"fluentci/dagger/function","title":"with_description","content":"pub fn with_description(\n  f: Function,\n  description: String,\n) -&gt; Function\n\nSynonyms:\nfluentci/dagger/function.with_description\nfluentci/dagger/function with_description","url":"fluentci/dagger/function.html#with_description"},{"doc":"fluentci/dagger/function","title":"fluentci/dagger/function","content":"","url":"fluentci/dagger/function.html"},{"doc":"fluentci/dagger/function_call_arg_value","title":"FunctionCallArgValue","content":"pub type FunctionCallArgValue\n\n\nSynonyms:\nfluentci/dagger/function_call_arg_value.FunctionCallArgValue\nfluentci/dagger/function_call_arg_value FunctionCallArgValue","url":"fluentci/dagger/function_call_arg_value.html#FunctionCallArgValue"},{"doc":"fluentci/dagger/function_call_arg_value","title":"id","content":"pub fn id(f: FunctionCallArgValue) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function_call_arg_value.id\nfluentci/dagger/function_call_arg_value id","url":"fluentci/dagger/function_call_arg_value.html#id"},{"doc":"fluentci/dagger/function_call_arg_value","title":"name","content":"pub fn name(f: FunctionCallArgValue) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function_call_arg_value.name\nfluentci/dagger/function_call_arg_value name","url":"fluentci/dagger/function_call_arg_value.html#name"},{"doc":"fluentci/dagger/function_call_arg_value","title":"value","content":"pub fn value(f: FunctionCallArgValue) -&gt; Promise(JSON)\n\nSynonyms:\nfluentci/dagger/function_call_arg_value.value\nfluentci/dagger/function_call_arg_value value","url":"fluentci/dagger/function_call_arg_value.html#value"},{"doc":"fluentci/dagger/function_call_arg_value","title":"fluentci/dagger/function_call_arg_value","content":"","url":"fluentci/dagger/function_call_arg_value.html"},{"doc":"fluentci/dagger/function_call","title":"FunctionCall","content":"pub type FunctionCall\n\n\nSynonyms:\nfluentci/dagger/function_call.FunctionCall\nfluentci/dagger/function_call FunctionCall","url":"fluentci/dagger/function_call.html#FunctionCall"},{"doc":"fluentci/dagger/function_call","title":"id","content":"pub fn id(f: FunctionCall) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function_call.id\nfluentci/dagger/function_call id","url":"fluentci/dagger/function_call.html#id"},{"doc":"fluentci/dagger/function_call","title":"input_args","content":"pub fn input_args(\n  f: FunctionCall,\n) -&gt; Promise(Array(FunctionCallArgValue))\n\nSynonyms:\nfluentci/dagger/function_call.input_args\nfluentci/dagger/function_call input_args","url":"fluentci/dagger/function_call.html#input_args"},{"doc":"fluentci/dagger/function_call","title":"name","content":"pub fn name(f: FunctionCall) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function_call.name\nfluentci/dagger/function_call name","url":"fluentci/dagger/function_call.html#name"},{"doc":"fluentci/dagger/function_call","title":"parent","content":"pub fn parent(f: FunctionCall) -&gt; Promise(JSON)\n\nSynonyms:\nfluentci/dagger/function_call.parent\nfluentci/dagger/function_call parent","url":"fluentci/dagger/function_call.html#parent"},{"doc":"fluentci/dagger/function_call","title":"parent_name","content":"pub fn parent_name(f: FunctionCall) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/function_call.parent_name\nfluentci/dagger/function_call parent_name","url":"fluentci/dagger/function_call.html#parent_name"},{"doc":"fluentci/dagger/function_call","title":"return_value","content":"pub fn return_value(\n  f: FunctionCall,\n  value: JSON,\n) -&gt; Promise(Void)\n\nSynonyms:\nfluentci/dagger/function_call.return_value\nfluentci/dagger/function_call return_value","url":"fluentci/dagger/function_call.html#return_value"},{"doc":"fluentci/dagger/function_call","title":"fluentci/dagger/function_call","content":"","url":"fluentci/dagger/function_call.html"},{"doc":"fluentci/dagger/generated_code","title":"GeneratedCode","content":"pub type GeneratedCode\n\n\nSynonyms:\nfluentci/dagger/generated_code.GeneratedCode\nfluentci/dagger/generated_code GeneratedCode","url":"fluentci/dagger/generated_code.html#GeneratedCode"},{"doc":"fluentci/dagger/generated_code","title":"code","content":"pub fn code(f: GeneratedCode) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/generated_code.code\nfluentci/dagger/generated_code code","url":"fluentci/dagger/generated_code.html#code"},{"doc":"fluentci/dagger/generated_code","title":"id","content":"pub fn id(f: GeneratedCode) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/generated_code.id\nfluentci/dagger/generated_code id","url":"fluentci/dagger/generated_code.html#id"},{"doc":"fluentci/dagger/generated_code","title":"vcs_generated_paths","content":"pub fn vcs_generated_paths(\n  f: GeneratedCode,\n) -&gt; Promise(Array(String))\n\nSynonyms:\nfluentci/dagger/generated_code.vcs_generated_paths\nfluentci/dagger/generated_code vcs_generated_paths","url":"fluentci/dagger/generated_code.html#vcs_generated_paths"},{"doc":"fluentci/dagger/generated_code","title":"vcs_ignored_paths","content":"pub fn vcs_ignored_paths(\n  f: GeneratedCode,\n) -&gt; Promise(Array(String))\n\nSynonyms:\nfluentci/dagger/generated_code.vcs_ignored_paths\nfluentci/dagger/generated_code vcs_ignored_paths","url":"fluentci/dagger/generated_code.html#vcs_ignored_paths"},{"doc":"fluentci/dagger/generated_code","title":"with_vsc_generated_paths","content":"pub fn with_vsc_generated_paths(\n  f: GeneratedCode,\n  paths: Array(String),\n) -&gt; GeneratedCode\n\nSynonyms:\nfluentci/dagger/generated_code.with_vsc_generated_paths\nfluentci/dagger/generated_code with_vsc_generated_paths","url":"fluentci/dagger/generated_code.html#with_vsc_generated_paths"},{"doc":"fluentci/dagger/generated_code","title":"with_vsc_ignored_paths","content":"pub fn with_vsc_ignored_paths(\n  f: GeneratedCode,\n  paths: Array(String),\n) -&gt; GeneratedCode\n\nSynonyms:\nfluentci/dagger/generated_code.with_vsc_ignored_paths\nfluentci/dagger/generated_code with_vsc_ignored_paths","url":"fluentci/dagger/generated_code.html#with_vsc_ignored_paths"},{"doc":"fluentci/dagger/generated_code","title":"fluentci/dagger/generated_code","content":"","url":"fluentci/dagger/generated_code.html"},{"doc":"fluentci/dagger/git_module_source","title":"GitModuleSource","content":"pub type GitModuleSource\n\n\nSynonyms:\nfluentci/dagger/git_module_source.GitModuleSource\nfluentci/dagger/git_module_source GitModuleSource","url":"fluentci/dagger/git_module_source.html#GitModuleSource"},{"doc":"fluentci/dagger/git_module_source","title":"clone_url","content":"pub fn clone_url(\n  module_source: GitModuleSource,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/git_module_source.clone_url\nfluentci/dagger/git_module_source clone_url","url":"fluentci/dagger/git_module_source.html#clone_url"},{"doc":"fluentci/dagger/git_module_source","title":"commit","content":"pub fn commit(module_source: GitModuleSource) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/git_module_source.commit\nfluentci/dagger/git_module_source commit","url":"fluentci/dagger/git_module_source.html#commit"},{"doc":"fluentci/dagger/git_module_source","title":"context_directory","content":"pub fn context_directory(\n  module_source: GitModuleSource,\n) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/git_module_source.context_directory\nfluentci/dagger/git_module_source context_directory","url":"fluentci/dagger/git_module_source.html#context_directory"},{"doc":"fluentci/dagger/git_module_source","title":"html_url","content":"pub fn html_url(\n  module_source: GitModuleSource,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/git_module_source.html_url\nfluentci/dagger/git_module_source html_url","url":"fluentci/dagger/git_module_source.html#html_url"},{"doc":"fluentci/dagger/git_module_source","title":"id","content":"pub fn id(module_source: GitModuleSource) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/git_module_source.id\nfluentci/dagger/git_module_source id","url":"fluentci/dagger/git_module_source.html#id"},{"doc":"fluentci/dagger/git_module_source","title":"root","content":"pub fn root(module_source: GitModuleSource) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/git_module_source.root\nfluentci/dagger/git_module_source root","url":"fluentci/dagger/git_module_source.html#root"},{"doc":"fluentci/dagger/git_module_source","title":"root_subpath","content":"pub fn root_subpath(\n  module_source: GitModuleSource,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/git_module_source.root_subpath\nfluentci/dagger/git_module_source root_subpath","url":"fluentci/dagger/git_module_source.html#root_subpath"},{"doc":"fluentci/dagger/git_module_source","title":"version","content":"pub fn version(module_source: GitModuleSource) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/git_module_source.version\nfluentci/dagger/git_module_source version","url":"fluentci/dagger/git_module_source.html#version"},{"doc":"fluentci/dagger/git_module_source","title":"fluentci/dagger/git_module_source","content":"","url":"fluentci/dagger/git_module_source.html"},{"doc":"fluentci/dagger/local_module_source","title":"LocalModuleSource","content":"pub type LocalModuleSource\n\n\nSynonyms:\nfluentci/dagger/local_module_source.LocalModuleSource\nfluentci/dagger/local_module_source LocalModuleSource","url":"fluentci/dagger/local_module_source.html#LocalModuleSource"},{"doc":"fluentci/dagger/local_module_source","title":"id","content":"pub fn id(module_source: LocalModuleSource) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/local_module_source.id\nfluentci/dagger/local_module_source id","url":"fluentci/dagger/local_module_source.html#id"},{"doc":"fluentci/dagger/local_module_source","title":"fluentci/dagger/local_module_source","content":"","url":"fluentci/dagger/local_module_source.html"},{"doc":"fluentci/dagger/module_dependency","title":"id","content":"pub fn id(module_dependency: ModuleDependency) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_dependency.id\nfluentci/dagger/module_dependency id","url":"fluentci/dagger/module_dependency.html#id"},{"doc":"fluentci/dagger/module_dependency","title":"name","content":"pub fn name(\n  module_dependency: ModuleDependency,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_dependency.name\nfluentci/dagger/module_dependency name","url":"fluentci/dagger/module_dependency.html#name"},{"doc":"fluentci/dagger/module_dependency","title":"source","content":"pub fn source(\n  module_dependency: ModuleDependency,\n) -&gt; ModuleSource\n\nSynonyms:\nfluentci/dagger/module_dependency.source\nfluentci/dagger/module_dependency source","url":"fluentci/dagger/module_dependency.html#source"},{"doc":"fluentci/dagger/module_dependency","title":"fluentci/dagger/module_dependency","content":"","url":"fluentci/dagger/module_dependency.html"},{"doc":"fluentci/dagger/module_source","title":"as_git_source","content":"pub fn as_git_source(\n  module_source: ModuleSource,\n) -&gt; GitModuleSource\n\nSynonyms:\nfluentci/dagger/module_source.as_git_source\nfluentci/dagger/module_source as_git_source","url":"fluentci/dagger/module_source.html#as_git_source"},{"doc":"fluentci/dagger/module_source","title":"as_local_source","content":"pub fn as_local_source(\n  module_source: ModuleSource,\n) -&gt; LocalModuleSource\n\nSynonyms:\nfluentci/dagger/module_source.as_local_source\nfluentci/dagger/module_source as_local_source","url":"fluentci/dagger/module_source.html#as_local_source"},{"doc":"fluentci/dagger/module_source","title":"as_module","content":"pub fn as_module(module_source: ModuleSource) -&gt; Module\n\nSynonyms:\nfluentci/dagger/module_source.as_module\nfluentci/dagger/module_source as_module","url":"fluentci/dagger/module_source.html#as_module"},{"doc":"fluentci/dagger/module_source","title":"as_string","content":"pub fn as_string(module_source: ModuleSource) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_source.as_string\nfluentci/dagger/module_source as_string","url":"fluentci/dagger/module_source.html#as_string"},{"doc":"fluentci/dagger/module_source","title":"config_exists","content":"pub fn config_exists(module_source: ModuleSource) -&gt; Promise(a)\n\nSynonyms:\nfluentci/dagger/module_source.config_exists\nfluentci/dagger/module_source config_exists","url":"fluentci/dagger/module_source.html#config_exists"},{"doc":"fluentci/dagger/module_source","title":"context_directory","content":"pub fn context_directory(\n  module_source: ModuleSource,\n) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/module_source.context_directory\nfluentci/dagger/module_source context_directory","url":"fluentci/dagger/module_source.html#context_directory"},{"doc":"fluentci/dagger/module_source","title":"dependencies","content":"pub fn dependencies(\n  module_source: ModuleSource,\n) -&gt; Promise(Array(ModuleDependency))\n\nSynonyms:\nfluentci/dagger/module_source.dependencies\nfluentci/dagger/module_source dependencies","url":"fluentci/dagger/module_source.html#dependencies"},{"doc":"fluentci/dagger/module_source","title":"directory","content":"pub fn directory(\n  module_source: ModuleSource,\n  path: String,\n) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/module_source.directory\nfluentci/dagger/module_source directory","url":"fluentci/dagger/module_source.html#directory"},{"doc":"fluentci/dagger/module_source","title":"id","content":"pub fn id(module_source: ModuleSource) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_source.id\nfluentci/dagger/module_source id","url":"fluentci/dagger/module_source.html#id"},{"doc":"fluentci/dagger/module_source","title":"kind","content":"pub fn kind(module_source: ModuleSource) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_source.kind\nfluentci/dagger/module_source kind","url":"fluentci/dagger/module_source.html#kind"},{"doc":"fluentci/dagger/module_source","title":"module_name","content":"pub fn module_name(\n  module_source: ModuleSource,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_source.module_name\nfluentci/dagger/module_source module_name","url":"fluentci/dagger/module_source.html#module_name"},{"doc":"fluentci/dagger/module_source","title":"module_original_name","content":"pub fn module_original_name(\n  module_source: ModuleSource,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_source.module_original_name\nfluentci/dagger/module_source module_original_name","url":"fluentci/dagger/module_source.html#module_original_name"},{"doc":"fluentci/dagger/module_source","title":"resolve_context_path_from_caller","content":"pub fn resolve_context_path_from_caller(\n  module_source: ModuleSource,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_source.resolve_context_path_from_caller\nfluentci/dagger/module_source resolve_context_path_from_caller","url":"fluentci/dagger/module_source.html#resolve_context_path_from_caller"},{"doc":"fluentci/dagger/module_source","title":"resolve_dependency","content":"pub fn resolve_dependency(\n  module_source: ModuleSource,\n  dep: ModuleSource,\n) -&gt; ModuleSource\n\nSynonyms:\nfluentci/dagger/module_source.resolve_dependency\nfluentci/dagger/module_source resolve_dependency","url":"fluentci/dagger/module_source.html#resolve_dependency"},{"doc":"fluentci/dagger/module_source","title":"resolve_directory_from_caller","content":"pub fn resolve_directory_from_caller(\n  module_source: ModuleSource,\n  path: String,\n) -&gt; Directory\n\nSynonyms:\nfluentci/dagger/module_source.resolve_directory_from_caller\nfluentci/dagger/module_source resolve_directory_from_caller","url":"fluentci/dagger/module_source.html#resolve_directory_from_caller"},{"doc":"fluentci/dagger/module_source","title":"resolve_from_caller","content":"pub fn resolve_from_caller(\n  module_source: ModuleSource,\n) -&gt; ModuleSource\n\nSynonyms:\nfluentci/dagger/module_source.resolve_from_caller\nfluentci/dagger/module_source resolve_from_caller","url":"fluentci/dagger/module_source.html#resolve_from_caller"},{"doc":"fluentci/dagger/module_source","title":"source_dubpath","content":"pub fn source_dubpath(\n  module_source: ModuleSource,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_source.source_dubpath\nfluentci/dagger/module_source source_dubpath","url":"fluentci/dagger/module_source.html#source_dubpath"},{"doc":"fluentci/dagger/module_source","title":"source_root_subpath","content":"pub fn source_root_subpath(\n  module_source: ModuleSource,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_source.source_root_subpath\nfluentci/dagger/module_source source_root_subpath","url":"fluentci/dagger/module_source.html#source_root_subpath"},{"doc":"fluentci/dagger/module_source","title":"view","content":"pub fn view(\n  module_source: ModuleSource,\n  name: String,\n) -&gt; ModuleSourceView\n\nSynonyms:\nfluentci/dagger/module_source.view\nfluentci/dagger/module_source view","url":"fluentci/dagger/module_source.html#view"},{"doc":"fluentci/dagger/module_source","title":"views","content":"pub fn views(\n  module_source: ModuleSource,\n) -&gt; Promise(Array(ModuleSourceView))\n\nSynonyms:\nfluentci/dagger/module_source.views\nfluentci/dagger/module_source views","url":"fluentci/dagger/module_source.html#views"},{"doc":"fluentci/dagger/module_source","title":"with_context_directory","content":"pub fn with_context_directory(\n  module_source: ModuleSource,\n  directory: Directory,\n) -&gt; ModuleSource\n\nSynonyms:\nfluentci/dagger/module_source.with_context_directory\nfluentci/dagger/module_source with_context_directory","url":"fluentci/dagger/module_source.html#with_context_directory"},{"doc":"fluentci/dagger/module_source","title":"with_dependencies","content":"pub fn with_dependencies(\n  module_source: ModuleSource,\n  dependencies: Array(ModuleDependency),\n) -&gt; ModuleSource\n\nSynonyms:\nfluentci/dagger/module_source.with_dependencies\nfluentci/dagger/module_source with_dependencies","url":"fluentci/dagger/module_source.html#with_dependencies"},{"doc":"fluentci/dagger/module_source","title":"with_name","content":"pub fn with_name(\n  module_source: ModuleSource,\n  name: String,\n) -&gt; ModuleSource\n\nSynonyms:\nfluentci/dagger/module_source.with_name\nfluentci/dagger/module_source with_name","url":"fluentci/dagger/module_source.html#with_name"},{"doc":"fluentci/dagger/module_source","title":"with_sdk","content":"pub fn with_sdk(\n  module_source: ModuleSource,\n  sdk: String,\n) -&gt; ModuleSource\n\nSynonyms:\nfluentci/dagger/module_source.with_sdk\nfluentci/dagger/module_source with_sdk","url":"fluentci/dagger/module_source.html#with_sdk"},{"doc":"fluentci/dagger/module_source","title":"with_source_subpath","content":"pub fn with_source_subpath(\n  module_source: ModuleSource,\n  path: String,\n) -&gt; ModuleSource\n\nSynonyms:\nfluentci/dagger/module_source.with_source_subpath\nfluentci/dagger/module_source with_source_subpath","url":"fluentci/dagger/module_source.html#with_source_subpath"},{"doc":"fluentci/dagger/module_source","title":"with_view","content":"pub fn with_view(\n  module_source: ModuleSource,\n  patterns: Array(String),\n) -&gt; ModuleSource\n\nSynonyms:\nfluentci/dagger/module_source.with_view\nfluentci/dagger/module_source with_view","url":"fluentci/dagger/module_source.html#with_view"},{"doc":"fluentci/dagger/module_source","title":"fluentci/dagger/module_source","content":"","url":"fluentci/dagger/module_source.html"},{"doc":"fluentci/dagger/module_source_view","title":"id","content":"pub fn id(\n  module_source_view: ModuleSourceView,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_source_view.id\nfluentci/dagger/module_source_view id","url":"fluentci/dagger/module_source_view.html#id"},{"doc":"fluentci/dagger/module_source_view","title":"name","content":"pub fn name(\n  module_source_view: ModuleSourceView,\n) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/module_source_view.name\nfluentci/dagger/module_source_view name","url":"fluentci/dagger/module_source_view.html#name"},{"doc":"fluentci/dagger/module_source_view","title":"patterns","content":"pub fn patterns(\n  module_source_view: ModuleSourceView,\n) -&gt; Promise(Array(String))\n\nSynonyms:\nfluentci/dagger/module_source_view.patterns\nfluentci/dagger/module_source_view patterns","url":"fluentci/dagger/module_source_view.html#patterns"},{"doc":"fluentci/dagger/module_source_view","title":"fluentci/dagger/module_source_view","content":"","url":"fluentci/dagger/module_source_view.html"},{"doc":"fluentci/dagger/terminal","title":"Terminal","content":"pub type Terminal\n\n\nSynonyms:\nfluentci/dagger/terminal.Terminal\nfluentci/dagger/terminal Terminal","url":"fluentci/dagger/terminal.html#Terminal"},{"doc":"fluentci/dagger/terminal","title":"id","content":"pub fn id(terminal: Terminal) -&gt; Promise(String)\n\nSynonyms:\nfluentci/dagger/terminal.id\nfluentci/dagger/terminal id","url":"fluentci/dagger/terminal.html#id"},{"doc":"fluentci/dagger/terminal","title":"fluentci/dagger/terminal","content":"","url":"fluentci/dagger/terminal.html"},{"doc":"fluentci/file","title":"chmod","content":"pub fn chmod(f: File, mode: a) -&gt; Promise(File)\n\nSynonyms:\nfluentci/file.chmod\nfluentci/file chmod","url":"fluentci/file.html#chmod"},{"doc":"fluentci/file","title":"id","content":"pub fn id(f: File) -&gt; Promise(String)\n\nSynonyms:\nfluentci/file.id\nfluentci/file id","url":"fluentci/file.html#id"},{"doc":"fluentci/file","title":"md5","content":"pub fn md5(f: File) -&gt; Promise(String)\n\nSynonyms:\nfluentci/file.md5\nfluentci/file md5","url":"fluentci/file.html#md5"},{"doc":"fluentci/file","title":"path","content":"pub fn path(f: File) -&gt; Promise(String)\n\nSynonyms:\nfluentci/file.path\nfluentci/file path","url":"fluentci/file.html#path"},{"doc":"fluentci/file","title":"sha256","content":"pub fn sha256(f: File) -&gt; Promise(String)\n\nSynonyms:\nfluentci/file.sha256\nfluentci/file sha256","url":"fluentci/file.html#sha256"},{"doc":"fluentci/file","title":"tar_czvf","content":"pub fn tar_czvf(f: File, output_dir: String) -&gt; Directory\n\nSynonyms:\nfluentci/file.tar_czvf\nfluentci/file tar_czvf","url":"fluentci/file.html#tar_czvf"},{"doc":"fluentci/file","title":"unzip","content":"pub fn unzip(f: File, output_dir: String) -&gt; Directory\n\nSynonyms:\nfluentci/file.unzip\nfluentci/file unzip","url":"fluentci/file.html#unzip"},{"doc":"fluentci/file","title":"zip","content":"pub fn zip(f: File) -&gt; Directory\n\nSynonyms:\nfluentci/file.zip\nfluentci/file zip","url":"fluentci/file.html#zip"},{"doc":"fluentci/file","title":"fluentci/file","content":"","url":"fluentci/file.html"}]);